(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     16456,        417]
NotebookOptionsPosition[     15868,        392]
NotebookOutlinePosition[     16209,        407]
CellTagsIndexPosition[     16166,        404]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Example 3.3.4", "Subtitle",
 CellChangeTimes->{{3.4851870005322857`*^9, 3.4851870038807783`*^9}}],

Cell["\<\
This notebook contains a manipulation to illustrate Example 3.3.4 of the \
text.  This example explores how the solution to the system of linear \
equations\
\>", "Text",
 CellChangeTimes->{{3.4851870407705584`*^9, 3.4851871195926867`*^9}}],

Cell[TextData[Cell[BoxData[
 FormBox[GridBox[{
    {GridBox[{
       {
        RowBox[{
         RowBox[{
          RowBox[{"5", "x"}], "-", 
          RowBox[{"2", "y"}], "+", 
          RowBox[{"8", "z"}]}], "=", "15"}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], "x"}], "+", 
          RowBox[{"9", "y"}], "+", 
          RowBox[{"11", "z"}]}], "=", 
         RowBox[{"-", "4"}]}]},
       {
        RowBox[{
         RowBox[{
          RowBox[{"2", "x"}], "+", 
          RowBox[{"7", "y"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"18.7", "+", "R"}], ")"}], "z"}]}], "=", "20"}]}
      },
      GridBoxAlignment->{"Columns" -> {{"="}}}]}
   },
   GridBoxItemSize->{"Columns" -> {{
        Scaled[0.96]}}}], TraditionalForm]]]], "Text",
 CellChangeTimes->{
  3.485187114351596*^9, {3.485187144394169*^9, 3.485187187978942*^9}}],

Cell[TextData[{
 "changes as the value of ",
 Cell[BoxData[
  FormBox["R", TraditionalForm]]],
 " runs over the range -1 to 3.  We consider ",
 Cell[BoxData[
  FormBox[
   RowBox[{"R", "=", "0"}], TraditionalForm]]],
 " to be an \"exact\" system with an \"exact\" solution ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", GridBox[{
      {
       FractionBox["2947", "39"], 
       FractionBox["2395", "39"], 
       RowBox[{"-", "30"}]}
     }], ")"}], TraditionalForm]]],
 ", and nonzero values of ",
 Cell[BoxData[
  FormBox["R", TraditionalForm]]],
 " to have introduced an error into the system, resulting in an \"approximate\
\" solution.  The manipulation below allows you to vary the values of ",
 Cell[BoxData[
  FormBox["R", TraditionalForm]]],
 " from -1 to 3, and produces two graphs to illustrate what is happening.\n\n\
The top graph shows the graph of the exact solution (in black) along with the \
graph of the approximate solution for the current value of ",
 Cell[BoxData[
  FormBox["R", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " (in green).  To help visualize this, the solution to just the first two \
equations by themselves is shown as a line (in red).  The graph of just the \
third equation is shown as a mostly transparent plane.  The approximate \
solution is where the line intersects the plane. Changing the value for ",
 Cell[BoxData[
  FormBox["R", TraditionalForm]]],
 " changes the \"tilt\" of this plane slightly (you will need to change the \
value of ",
 Cell[BoxData[
  FormBox["R", TraditionalForm]]],
 " by a decent amount to see the \"tilt\" vary noticeably), shifting the \
point of intersection.  The 3-D graphic can be rotated inside the \
manipulation if you wish to see it from different angles.\n\nThe bottom graph \
is a graph of the distance between the exact solution and the approximate \
solution as ",
 Cell[BoxData[
  FormBox["R", TraditionalForm]]],
 " goes from -1 to 3.  A vertical line is placed at the current value of ",
 Cell[BoxData[
  FormBox["R", TraditionalForm]]],
 " to make it easier to match the top graphic with the bottom one - as the \
two points move apart, the value on the distance graph should become greater.\
\n\nAs noted in the text, the graph has a vertical asymptote at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"R", "=", "0.3"}], TraditionalForm]]],
 "; in the top graphic this corresponds to the tilt of the plane matching \
that of the line.  As the tilt gets closer and closer to a perfect match the \
approximate solution slides off to infinity."
}], "Text",
 CellChangeTimes->{{3.485187193656241*^9, 3.485187239667225*^9}, {
  3.485187272682049*^9, 3.485187316436915*^9}, {3.4851873621135178`*^9, 
  3.4851880475668287`*^9}, {3.4851886257338*^9, 3.4851886837667217`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Visualize334", "[", "rval_", "]"}], ":=", "\[IndentingNewLine]", 
    
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "line", ",", " ", "plane", ",", "generalsolution", ",", "point0", ",", 
        " ", "pointr", ",", "r", ",", "t", ",", " ", "leftgraphic", ",", 
        "rightgraphic", ",", "distance"}], "}"}], ",", "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"line", "=", " ", 
        RowBox[{"ParametricPlot3D", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"t", ",", 
            RowBox[{
             FractionBox["1", "94"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "197"}], "+", 
               RowBox[{"79", " ", "t"}]}], ")"}]}], ",", 
            RowBox[{
             FractionBox["1", "94"], " ", 
             RowBox[{"(", 
              RowBox[{"127", "-", 
               RowBox[{"39", " ", "t"}]}], ")"}]}]}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"t", ",", 
            RowBox[{"-", "400"}], ",", "400"}], "}"}], ",", " ", 
          RowBox[{"PlotStyle", "\[Rule]", " ", 
           RowBox[{"{", 
            RowBox[{"Thick", ",", " ", "Red"}], "}"}]}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"plane", "=", 
        RowBox[{"Plot3D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"20", "-", 
             RowBox[{"2", "x"}], "-", 
             RowBox[{"7", "y"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"18.7", "+", "rval"}], ")"}]}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"x", ",", 
            RowBox[{"-", "400"}], ",", "400"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"y", ",", 
            RowBox[{"-", "400"}], ",", "400"}], "}"}], ",", " ", 
          RowBox[{"Mesh", "\[Rule]", "False"}], ",", " ", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"Opacity", "[", ".3", "]"}]}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"generalsolution", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"8841", "-", 
             RowBox[{"1270", " ", "r"}]}], 
            RowBox[{"39", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "3"}], "+", 
               RowBox[{"10", " ", "r"}]}], ")"}]}]]}], ",", 
          FractionBox[
           RowBox[{"5", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1437"}], "+", 
              RowBox[{"50", " ", "r"}]}], ")"}]}], 
           RowBox[{"39", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "3"}], "+", 
              RowBox[{"10", " ", "r"}]}], ")"}]}]], ",", 
          FractionBox["90", 
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"10", " ", "r"}]}]]}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"point0", "=", 
        RowBox[{"generalsolution", "/.", " ", 
         RowBox[{"r", "\[Rule]", "0"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"pointr", "=", 
        RowBox[{"generalsolution", "/.", " ", 
         RowBox[{"r", "\[Rule]", "rval"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"distance", "=", 
        RowBox[{"Norm", "[", 
         RowBox[{"generalsolution", "-", "point0"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"leftgraphic", "=", 
        RowBox[{"Show", "[", 
         RowBox[{"line", ",", " ", "plane", ",", " ", 
          RowBox[{"Graphics3D", "[", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"PointSize", "[", ".03", "]"}], ",", " ", "Black", ",", 
             " ", 
             RowBox[{"Point", "[", "point0", "]"}], ",", " ", "Green", ",", 
             " ", 
             RowBox[{"Point", "[", "pointr", "]"}]}], "}"}], "]"}], ",", " ", 
          
          RowBox[{"AxesLabel", "\[Rule]", " ", 
           RowBox[{"{", 
            RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\""}], 
            "}"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"rightgraphic", "=", 
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{"Plot", "[", 
           RowBox[{"distance", ",", 
            RowBox[{"{", 
             RowBox[{"r", ",", 
              RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", " ", 
            RowBox[{"PlotRange", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"0", ",", "1000"}], "}"}]}], ",", " ", 
            RowBox[{
            "PlotLabel", "\[Rule]", " ", 
             "\"\<Distance between solutions\>\""}], ",", " ", 
            RowBox[{"AxesLabel", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"\"\<R\>\"", ",", "\"\< \>\""}], "}"}]}]}], "]"}], ",", 
          " ", 
          RowBox[{"Graphics", "[", 
           RowBox[{"Line", "[", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"rval", ",", "0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"rval", ",", "1000"}], "}"}]}], "}"}], "]"}], "]"}]}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"GraphicsArray", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "leftgraphic", "}"}], ",", 
            RowBox[{"{", "rightgraphic", "}"}]}], "}"}], "]"}], ",", " ", 
         RowBox[{"ImageSize", "\[Rule]", "250"}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "\[IndentingNewLine]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.4851854737971487`*^9, 3.485185607127285*^9}, {
   3.485185668255624*^9, 3.48518574207296*^9}, {3.48518578848263*^9, 
   3.4851859850690317`*^9}, {3.48518602361735*^9, 3.485186034214715*^9}, {
   3.4851861135847683`*^9, 3.485186146086493*^9}, {3.485186331496614*^9, 
   3.485186357016212*^9}, {3.485186441180378*^9, 3.48518646342171*^9}, {
   3.4851865023682957`*^9, 3.485186520784848*^9}, {3.485186586086636*^9, 
   3.485186846725775*^9}, 3.485186883780195*^9, {3.485188156820568*^9, 
   3.485188170449987*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Visualize334", "[", "r", "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"r", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"-", "1"}], ",", "3", ",", ".01", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", " ", 
   
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.48518598768044*^9, 3.4851859943789597`*^9}, {
  3.485186156788862*^9, 3.485186167835285*^9}, {3.4851862055497026`*^9, 
  3.4851862058752213`*^9}, {3.4851862587096252`*^9, 3.485186288794984*^9}, {
  3.485186879763938*^9, 3.485186879852721*^9}, {3.48518693892378*^9, 
  3.48518696156457*^9}, {3.485188521769937*^9, 3.485188525920135*^9}, {
  3.485188563602442*^9, 3.48518856686471*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`r$$ = -1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`r$$], -1}, -1, 3, 0.01}}, Typeset`size$$ = {
    313., {238., 244.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`r$6015$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`r$$ = -1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`r$$, $CellContext`r$6015$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`Visualize334[$CellContext`r$$], 
      "Specifications" :> {{{$CellContext`r$$, -1}, -1, 3, 0.01, Appearance -> 
         "Labeled"}}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{367., {292.21875, 298.78125}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`Visualize334[
         Pattern[$CellContext`rval$, 
          Blank[]]] := 
       Block[{$CellContext`line, $CellContext`plane, \
$CellContext`generalsolution, $CellContext`point0, $CellContext`pointr, \
$CellContext`r$$, $CellContext`t, $CellContext`leftgraphic, \
$CellContext`rightgraphic, $CellContext`distance}, $CellContext`line = 
          ParametricPlot3D[{$CellContext`t, (1/94) (-197 + 
              79 $CellContext`t), (1/94) (127 - 
              39 $CellContext`t)}, {$CellContext`t, -400, 400}, 
            PlotStyle -> {Thick, Red}]; $CellContext`plane = 
          Plot3D[(20 - 2 $CellContext`x - 7 $CellContext`y)/(
            18.7 + $CellContext`rval$), {$CellContext`x, -400, 
             400}, {$CellContext`y, -400, 400}, Mesh -> False, PlotStyle -> 
            Opacity[
             0.3]]; $CellContext`generalsolution = {-((8841 - 
              1270 $CellContext`r$$)/(39 (-3 + 10 $CellContext`r$$))), (
             5 (-1437 + 50 $CellContext`r$$))/(39 (-3 + 10 $CellContext`r$$)),
             90/(-3 + 10 $CellContext`r$$)}; $CellContext`point0 = 
          ReplaceAll[$CellContext`generalsolution, $CellContext`r$$ -> 
            0]; $CellContext`pointr = 
          ReplaceAll[$CellContext`generalsolution, $CellContext`r$$ -> \
$CellContext`rval$]; $CellContext`distance = 
          Norm[$CellContext`generalsolution - $CellContext`point0]; \
$CellContext`leftgraphic = Show[$CellContext`line, $CellContext`plane, 
            Graphics3D[{
              PointSize[0.03], Black, 
              Point[$CellContext`point0], Green, 
              Point[$CellContext`pointr]}], 
            AxesLabel -> {"x", "y", "z"}]; $CellContext`rightgraphic = Show[
            
            Plot[$CellContext`distance, {$CellContext`r$$, -1, 3}, 
             PlotRange -> {0, 1000}, PlotLabel -> 
             "Distance between solutions", AxesLabel -> {"R", " "}], 
            Graphics[
             Line[{{$CellContext`rval$, 0}, {$CellContext`rval$, 1000}}]]]; 
         Show[
           
           GraphicsArray[{{$CellContext`leftgraphic}, \
{$CellContext`rightgraphic}}], ImageSize -> 250]]}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.485185997776576*^9, 3.485186035997561*^9, {3.485186123678792*^9, 
   3.485186168589738*^9}, 3.4851862065332747`*^9, {3.48518625945404*^9, 
   3.4851862893339453`*^9}, 3.4851865339555798`*^9, 3.4851868866397667`*^9, {
   3.485186950766644*^9, 3.485186961954249*^9}, 3.485188175890283*^9, 
   3.4851885270172777`*^9, 3.4851885674997177`*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{816, 758},
WindowMargins->{{178, Automatic}, {63, Automatic}},
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 103, 1, 57, "Subtitle"],
Cell[673, 25, 250, 5, 51, "Text"],
Cell[926, 32, 913, 31, 77, "Text"],
Cell[1842, 65, 2764, 62, 402, "Text"],
Cell[4609, 129, 6257, 157, 23, "Input",
 CellOpen->False],
Cell[CellGroupData[{
Cell[10891, 290, 860, 19, 23, "Input",
 CellOpen->False],
Cell[11754, 311, 4086, 77, 611, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
