(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     26483,        645]
NotebookOptionsPosition[     25541,        608]
NotebookOutlinePosition[     25900,        624]
CellTagsIndexPosition[     25857,        621]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Example 4.1.3", "Subtitle",
 CellChangeTimes->{{3.48162710068998*^9, 3.481627103135716*^9}}],

Cell["\<\
This notebook simulates the discussion in Example 4.1.3 of the text.  Example \
4.1.3 talks about finding the conic through 5 points - 4 of which are fixed \
to be the corners of the \"unit square\", and the 5th is a point on a circle.

Two manipulations are included here. The first follows Example 4.1.3 exactly \
in that the fifth point is constrained to be on a circle of radius 1 centered \
at (0,1/2).  This point is in red and can be freely dragged around the \
circle, with both the equation and graph of the conic updated.  The second \
manipulation generalizes the problem by letting you enter the center and \
radius of the circle (so you could for example choose the circle centered at \
(3,2) with radius 5). Both manipulations will run without any evaluation. 

Be aware that for certain carefully chosen point placements in the second \
manipulation, there may not be a conic and an error will be returned (you may \
want to investigate this on your own and see if you can figure out what the \
placement must be).\
\>", "Text",
 CellChangeTimes->{{3.481627108338023*^9, 3.4816273253312283`*^9}, {
  3.481627418838039*^9, 3.481627513653545*^9}, {3.4816275546077347`*^9, 
  3.4816275797023487`*^9}, {3.481627691728037*^9, 3.481627698480013*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ConicThrough5Points", "[", 
     RowBox[{
     "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "x_", ",", "y_"}],
      "]"}], ":=", " ", 
    RowBox[{"Block", "[", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "eqns", ",", " ", "conic", ",", "b1", ",", "c1", ",", "d1", ",", "e1", 
        ",", "f1"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"eqns", " ", "=", " ", 
        RowBox[{
         RowBox[{"(", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"x", "^", "2"}], "  ", "+", " ", 
            RowBox[{"b1", " ", "x", " ", "y"}], " ", "+", " ", 
            RowBox[{"c1", " ", 
             RowBox[{"y", "^", "2"}]}], " ", "+", " ", 
            RowBox[{"d1", " ", "x"}], "+", " ", 
            RowBox[{"e1", " ", "y"}], " ", "+", " ", "f1"}], "\[Equal]", 
           "0"}], ")"}], "/.", " ", 
         RowBox[{"{", " ", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"x", "\[Rule]", 
              RowBox[{"a", "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
             RowBox[{"y", "\[Rule]", 
              RowBox[{"a", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"x", "\[Rule]", 
              RowBox[{"b", "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
             RowBox[{"y", "\[Rule]", 
              RowBox[{"b", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"x", "\[Rule]", 
              RowBox[{"c", "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
             RowBox[{"y", "\[Rule]", 
              RowBox[{"c", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"x", "\[Rule]", 
              RowBox[{"d", "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
             RowBox[{"y", "\[Rule]", 
              RowBox[{"d", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"x", "\[Rule]", 
              RowBox[{"e", "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
             RowBox[{"y", "\[Rule]", 
              RowBox[{"e", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}]}], "}"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"conic", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"x", "^", "2"}], "  ", "+", " ", 
            RowBox[{"b1", " ", "x", " ", "y"}], " ", "+", " ", 
            RowBox[{"c1", " ", 
             RowBox[{"y", "^", "2"}]}], " ", "+", " ", 
            RowBox[{"d1", " ", "x"}], "+", " ", 
            RowBox[{"e1", " ", "y"}], " ", "+", " ", "f1"}], "\[Equal]", 
           "0"}], ")"}], "/.", " ", 
         RowBox[{
          RowBox[{"Solve", "[", " ", 
           RowBox[{"eqns", ",", 
            RowBox[{"{", 
             RowBox[{"b1", ",", "c1", ",", "d1", ",", "e1", ",", "f1"}], 
             "}"}]}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Return", "[", "conic", "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.481539100600868*^9, 3.48153914171669*^9}, {
   3.481539172065487*^9, 3.481539216303315*^9}, {3.48153924692173*^9, 
   3.4815393057004013`*^9}, {3.481539475601409*^9, 3.481539501073203*^9}, {
   3.4815395892923183`*^9, 3.4815396410113487`*^9}, {3.4815396985570927`*^9, 
   3.481539729051199*^9}, {3.481539769607051*^9, 3.481539775773753*^9}, {
   3.481539855552628*^9, 3.481539856806731*^9}, 3.481627056180422*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ConicFrame", "[", " ", "pt1_", "]"}], ":=", 
  RowBox[{"Block", "[", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "rawgraphics", ",", " ", "conic", ",", " ", "conicplot", ",", "x", ",", 
      "y", ",", "pt"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"pt", "=", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"1", "/", "2"}]}], "}"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"pt1", "-", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"1", "/", "2"}]}], "}"}]}], ")"}], "/", 
        RowBox[{"Norm", "[", 
         RowBox[{"pt1", "-", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"1", "/", "2"}]}], "}"}]}], "]"}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"rawgraphics", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", ".02", "]"}], ",", " ", "Black", ",", 
        RowBox[{"Point", "[", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "1"}], "}"}]}], "}"}], "]"}], ",", "Red", ",", 
        RowBox[{"Point", "[", "pt", "]"}], ",", " ", "Black", ",", " ", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"1", "/", "2"}]}], "}"}], ",", "1"}], "]"}]}], "}"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"conic", "=", 
      RowBox[{"ConicThrough5Points", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}], ",", "pt", ",", "x", ",", "y"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"conicplot", "=", 
      RowBox[{"ContourPlot", "[", 
       RowBox[{
        RowBox[{"Evaluate", "[", "conic", "]"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", 
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", " ", 
        RowBox[{"Frame", "\[Rule]", "False"}], ",", " ", 
        RowBox[{"Axes", "\[Rule]", "True"}], ",", " ", 
        RowBox[{"AxesOrigin", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], ",", " ", 
        RowBox[{"PlotPoints", "\[Rule]", "75"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Return", "[", 
      RowBox[{"Show", "[", " ", 
       RowBox[{"conicplot", ",", " ", 
        RowBox[{"Graphics", "[", "rawgraphics", "]"}], ",", " ", 
        RowBox[{"PlotLabel", "\[Rule]", " ", "conic"}]}], "]"}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ConicFrame2", "[", " ", 
   RowBox[{"pt1_", ",", "pt2_", ",", "r_"}], "]"}], ":=", 
  RowBox[{"Block", "[", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "rawgraphics", ",", " ", "conic", ",", " ", "conicplot", ",", "x", ",", 
      "y", ",", "pt"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"pt", "=", 
      RowBox[{"pt2", "+", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"pt1", "-", "pt2"}], ")"}], "/", 
         RowBox[{"Norm", "[", 
          RowBox[{"pt1", "-", "pt2"}], "]"}]}], "r"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"rawgraphics", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", ".02", "]"}], ",", " ", "Black", ",", 
        RowBox[{"Point", "[", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "1"}], "}"}]}], "}"}], "]"}], ",", "Red", ",", 
        RowBox[{"Point", "[", "pt", "]"}], ",", " ", "Black", ",", " ", 
        RowBox[{"Circle", "[", 
         RowBox[{"pt2", ",", "r"}], "]"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"conic", "=", 
      RowBox[{"ConicThrough5Points", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}], ",", "pt", ",", "x", ",", "y"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"conicplot", "=", 
      RowBox[{"ContourPlot", "[", 
       RowBox[{
        RowBox[{"Evaluate", "[", "conic", "]"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", 
          RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", " ", 
        RowBox[{"Frame", "\[Rule]", "False"}], ",", " ", 
        RowBox[{"Axes", "\[Rule]", "True"}], ",", " ", 
        RowBox[{"AxesOrigin", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], ",", " ", 
        RowBox[{"PlotPoints", "\[Rule]", "75"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Return", "[", 
      RowBox[{"Show", "[", " ", 
       RowBox[{"conicplot", ",", " ", 
        RowBox[{"Graphics", "[", "rawgraphics", "]"}], ",", " ", 
        RowBox[{"PlotLabel", "\[Rule]", " ", "conic"}]}], "]"}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]}], "Input",
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.481539867233844*^9, 3.481540107062715*^9}, {
   3.481540139953108*^9, 3.481540153969398*^9}, {3.481540201914168*^9, 
   3.4815402560413103`*^9}, {3.481540295508051*^9, 3.481540317739699*^9}, {
   3.481540633177288*^9, 3.481540698381896*^9}, {3.48154076091851*^9, 
   3.481540788848258*^9}, {3.48154082921049*^9, 3.4815408698747787`*^9}, {
   3.481540915885466*^9, 3.481540948987851*^9}, {3.4815409837967587`*^9, 
   3.4815409863372393`*^9}, {3.481541239041541*^9, 3.481541239311881*^9}, {
   3.481541407947701*^9, 3.4815414081697397`*^9}, {3.481541687583255*^9, 
   3.4815417301353283`*^9}, {3.481541895173317*^9, 3.481541897820208*^9}, 
   3.481627056180526*^9}]
}, Open  ]],

Cell["\<\
The original problem with a circle of radius 1 centered at (0,1/2):\
\>", "Text",
 CellChangeTimes->{{3.481627588990509*^9, 3.4816275892704697`*^9}, {
  3.481627638103157*^9, 3.481627654479453*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"ConicFrame", "[", "spot", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"spot", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"1", "/", "2"}]}], "}"}]}], "}"}], ",", "Locator", ",", " ", 
     
     RowBox[{"Appearance", "\[Rule]", "None"}]}], "}"}], ",", " ", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.4815400669792433`*^9, 3.481540069454833*^9}, {
  3.481540110023364*^9, 3.481540132096033*^9}, {3.48154038364645*^9, 
  3.48154042332612*^9}, {3.481540616156582*^9, 3.481540621769289*^9}, {
  3.481540653119047*^9, 3.481540657779043*^9}, {3.481540725209324*^9, 
  3.4815407432321167`*^9}, {3.481540877442277*^9, 3.4815408944190207`*^9}, {
  3.4815410644227743`*^9, 3.481541081056294*^9}, {3.4815412113831673`*^9, 
  3.481541228694871*^9}, {3.481541329114113*^9, 3.4815413339680653`*^9}, {
  3.4816269830172167`*^9, 3.481626988865094*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`spot$$ = {1, 
     Rational[1, 2]}, Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`spot$$], {1, 
        Rational[1, 2]}}, Automatic}}, Typeset`size$$ = {434., {224., 230.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`spot$$ = {1, 
          Rational[1, 2]}}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`ConicFrame[$CellContext`spot$$], 
      "Specifications" :> {{{$CellContext`spot$$, {1, 
           Rational[1, 2]}}, Automatic, ControlType -> Locator, Appearance -> 
         None}}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{495., {262.21875, 268.78125}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`ConicFrame[
         Pattern[$CellContext`pt1, 
          Blank[]]] := 
       Block[{$CellContext`rawgraphics, $CellContext`conic, \
$CellContext`conicplot, $CellContext`x, $CellContext`y, $CellContext`pt}, \
$CellContext`pt = {0, 1/2} + ($CellContext`pt1 - {0, 1/2})/
            Norm[$CellContext`pt1 - {0, 1/2}]; $CellContext`rawgraphics = {
            PointSize[0.02], Black, 
            Point[{{0, 0}, {0, 1}, {1, 0}, {1, 1}}], Red, 
            Point[$CellContext`pt], Black, 
            
            Circle[{0, 1/2}, 
             1]}; $CellContext`conic = $CellContext`ConicThrough5Points[{1, 
            1}, {0, 0}, {1, 0}, {0, 
            
            1}, $CellContext`pt, $CellContext`x, $CellContext`y]; \
$CellContext`conicplot = ContourPlot[
            
            Evaluate[$CellContext`conic], {$CellContext`x, -5, 
             5}, {$CellContext`y, -5, 5}, Frame -> False, Axes -> True, 
            AxesOrigin -> {0, 0}, PlotPoints -> 75]; Return[
           Show[$CellContext`conicplot, 
            Graphics[$CellContext`rawgraphics], 
            PlotLabel -> $CellContext`conic]]], \
$CellContext`ConicThrough5Points[
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`c, 
          Blank[]], 
         Pattern[$CellContext`d, 
          Blank[]], 
         Pattern[$CellContext`e, 
          Blank[]], 
         Pattern[$CellContext`x, 
          Blank[]], 
         Pattern[$CellContext`y, 
          Blank[]]] := 
       Block[{$CellContext`eqns, $CellContext`conic, $CellContext`b1, \
$CellContext`c1, $CellContext`d1, $CellContext`e1, $CellContext`f1}, \
$CellContext`eqns = 
          ReplaceAll[$CellContext`x^2 + $CellContext`b1 $CellContext`x \
$CellContext`y + $CellContext`c1 $CellContext`y^2 + $CellContext`d1 \
$CellContext`x + $CellContext`e1 $CellContext`y + $CellContext`f1 == 
            0, {{$CellContext`x -> Part[$CellContext`a, 1], $CellContext`y -> 
              Part[$CellContext`a, 2]}, {$CellContext`x -> 
              Part[$CellContext`b, 1], $CellContext`y -> 
              Part[$CellContext`b, 2]}, {$CellContext`x -> 
              Part[$CellContext`c, 1], $CellContext`y -> 
              Part[$CellContext`c, 2]}, {$CellContext`x -> 
              Part[$CellContext`d, 1], $CellContext`y -> 
              Part[$CellContext`d, 2]}, {$CellContext`x -> 
              Part[$CellContext`e, 1], $CellContext`y -> 
              Part[$CellContext`e, 2]}}]; $CellContext`conic = 
          ReplaceAll[$CellContext`x^2 + $CellContext`b1 $CellContext`x \
$CellContext`y + $CellContext`c1 $CellContext`y^2 + $CellContext`d1 \
$CellContext`x + $CellContext`e1 $CellContext`y + $CellContext`f1 == 0, 
            Part[
             
             Solve[$CellContext`eqns, {$CellContext`b1, $CellContext`c1, \
$CellContext`d1, $CellContext`e1, $CellContext`f1}], 1]]; 
         Return[$CellContext`conic]]}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.481540898030966*^9, {3.48154106756017*^9, 3.4815410819347878`*^9}, 
   3.4815412295440407`*^9, 3.4815413346734962`*^9, 3.481541404453924*^9, 
   3.4816269961994047`*^9, 3.481627059993968*^9, 3.481627545116583*^9}]
}, Open  ]],

Cell["The generalization with any circle you want to enter:", "Text",
 CellChangeTimes->{{3.4816276655914593`*^9, 3.4816276749835253`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"ConicFrame2", "[", 
    RowBox[{"spot", ",", "center", ",", "radius"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"spot", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", 
         RowBox[{"1", "/", "2"}]}], "}"}]}], "}"}], ",", "Locator", ",", " ", 
     
     RowBox[{"Appearance", "\[Rule]", "None"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"center", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"1", "/", "2"}]}], "}"}], ",", "\"\<Circle Center\>\""}], 
      "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "InputField"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"radius", ",", "1", ",", "\"\<Circle radius\>\""}], "}"}], ",", 
     " ", 
     RowBox[{"ControlType", "\[Rule]", "InputField"}]}], "}"}], ",", " ", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.481540958113674*^9, 3.48154096183436*^9}, {
  3.48154116851921*^9, 3.48154117078085*^9}, {3.481541749582849*^9, 
  3.4815418772252502`*^9}, {3.481627005284741*^9, 3.481627013891494*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`center$$ = {0, 
     Rational[1, 2]}, $CellContext`radius$$ = 1, $CellContext`spot$$ = {1, 
     Rational[1, 2]}, Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`spot$$], {1, 
        Rational[1, 2]}}, Automatic}, {{
       Hold[$CellContext`center$$], {0, 
        Rational[1, 2]}, "Circle Center"}}, {{
       Hold[$CellContext`radius$$], 1, "Circle radius"}}}, Typeset`size$$ = {
    434., {224., 230.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`center$$ = {0, 
          Rational[1, 2]}, $CellContext`radius$$ = 
        1, $CellContext`spot$$ = {1, 
          Rational[1, 2]}}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`ConicFrame2[$CellContext`spot$$, \
$CellContext`center$$, $CellContext`radius$$], 
      "Specifications" :> {{{$CellContext`spot$$, {1, 
           Rational[1, 2]}}, Automatic, ControlType -> Locator, Appearance -> 
         None}, {{$CellContext`center$$, {0, 
           Rational[1, 2]}, "Circle Center"}, ControlType -> 
         InputField}, {{$CellContext`radius$$, 1, "Circle radius"}, 
         ControlType -> InputField}}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{495., {301.21875, 307.78125}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`ConicFrame2[
         Pattern[$CellContext`pt1, 
          Blank[]], 
         Pattern[$CellContext`pt2, 
          Blank[]], 
         Pattern[$CellContext`r, 
          Blank[]]] := 
       Block[{$CellContext`rawgraphics, $CellContext`conic, \
$CellContext`conicplot, $CellContext`x, $CellContext`y, $CellContext`pt}, \
$CellContext`pt = $CellContext`pt2 + (($CellContext`pt1 - $CellContext`pt2)/
             Norm[$CellContext`pt1 - $CellContext`pt2]) $CellContext`r; \
$CellContext`rawgraphics = {
            PointSize[0.02], Black, 
            Point[{{0, 0}, {0, 1}, {1, 0}, {1, 1}}], Red, 
            Point[$CellContext`pt], Black, 
            
            Circle[$CellContext`pt2, $CellContext`r]}; $CellContext`conic = \
$CellContext`ConicThrough5Points[{1, 1}, {0, 0}, {1, 0}, {0, 
            1}, $CellContext`pt, $CellContext`x, $CellContext`y]; \
$CellContext`conicplot = ContourPlot[
            
            Evaluate[$CellContext`conic], {$CellContext`x, -5, 
             5}, {$CellContext`y, -5, 5}, Frame -> False, Axes -> True, 
            AxesOrigin -> {0, 0}, PlotPoints -> 75]; Return[
           Show[$CellContext`conicplot, 
            Graphics[$CellContext`rawgraphics], 
            PlotLabel -> $CellContext`conic]]], \
$CellContext`ConicThrough5Points[
         Pattern[$CellContext`a, 
          Blank[]], 
         Pattern[$CellContext`b, 
          Blank[]], 
         Pattern[$CellContext`c, 
          Blank[]], 
         Pattern[$CellContext`d, 
          Blank[]], 
         Pattern[$CellContext`e, 
          Blank[]], 
         Pattern[$CellContext`x, 
          Blank[]], 
         Pattern[$CellContext`y, 
          Blank[]]] := 
       Block[{$CellContext`eqns, $CellContext`conic, $CellContext`b1, \
$CellContext`c1, $CellContext`d1, $CellContext`e1, $CellContext`f1}, \
$CellContext`eqns = 
          ReplaceAll[$CellContext`x^2 + $CellContext`b1 $CellContext`x \
$CellContext`y + $CellContext`c1 $CellContext`y^2 + $CellContext`d1 \
$CellContext`x + $CellContext`e1 $CellContext`y + $CellContext`f1 == 
            0, {{$CellContext`x -> Part[$CellContext`a, 1], $CellContext`y -> 
              Part[$CellContext`a, 2]}, {$CellContext`x -> 
              Part[$CellContext`b, 1], $CellContext`y -> 
              Part[$CellContext`b, 2]}, {$CellContext`x -> 
              Part[$CellContext`c, 1], $CellContext`y -> 
              Part[$CellContext`c, 2]}, {$CellContext`x -> 
              Part[$CellContext`d, 1], $CellContext`y -> 
              Part[$CellContext`d, 2]}, {$CellContext`x -> 
              Part[$CellContext`e, 1], $CellContext`y -> 
              Part[$CellContext`e, 2]}}]; $CellContext`conic = 
          ReplaceAll[$CellContext`x^2 + $CellContext`b1 $CellContext`x \
$CellContext`y + $CellContext`c1 $CellContext`y^2 + $CellContext`d1 \
$CellContext`x + $CellContext`e1 $CellContext`y + $CellContext`f1 == 0, 
            Part[
             
             Solve[$CellContext`eqns, {$CellContext`b1, $CellContext`c1, \
$CellContext`d1, $CellContext`e1, $CellContext`f1}], 1]]; 
         Return[$CellContext`conic]]}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.481541864250517*^9, 3.4815418780785627`*^9}, 
   3.4815451187617188`*^9, 3.481627017944675*^9, 3.481627064873353*^9, 
   3.4816273800519753`*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{640, 750},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
ShowSelection->True,
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 98, 1, 57, "Subtitle"],
Cell[668, 25, 1269, 20, 314, "Text"],
Cell[CellGroupData[{
Cell[1962, 49, 3963, 98, 23, "Input",
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[5928, 149, 6626, 168, 23, "Input",
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]],
Cell[12569, 320, 208, 4, 32, "Text"],
Cell[CellGroupData[{
Cell[12802, 328, 1029, 22, 23, "Input",
 CellOpen->False],
Cell[13834, 352, 4815, 98, 551, "Output"]
}, Open  ]],
Cell[18664, 453, 139, 1, 32, "Text"],
Cell[CellGroupData[{
Cell[18828, 458, 1226, 33, 23, "Input",
 CellOpen->False],
Cell[20057, 493, 5456, 111, 629, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
