(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     13959,        360]
NotebookOptionsPosition[     13449,        337]
NotebookOutlinePosition[     13787,        352]
CellTagsIndexPosition[     13744,        349]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Example 4.4.2", "Subtitle",
 CellChangeTimes->{{3.481903016645164*^9, 3.4819030184834003`*^9}}],

Cell["\<\
This notebook shows an animation for example 4.4.2 in the text, which \
involves rotating a curve around a point.  You may enter any curve you want \
in terms of parametric coordinates (the functions for the x- and y- \
coordinates must be in terms of t) as well as a center for the rotation.  You \
may change the angle the curve is rotated through via the slider, which \
ranges over the angles from 0 to 2\[Pi].\
\>", "Text",
 CellChangeTimes->{{3.481903023910438*^9, 3.4819031393674507`*^9}, {
  3.4819033287884293`*^9, 3.4819033305143547`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DisplayRotatedCurve", "[", 
    RowBox[{"pt_", ",", " ", "theta_", ",", " ", "curve_", ",", 
     RowBox[{"{", 
      RowBox[{"tmin_", ",", "tmax_"}], "}"}]}], "]"}], ":=", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Block", "[", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "newcurve", ",", "t", ",", "xmax", ",", "xmin", ",", "ymax", ",", 
       "ymin", ",", "theta1", ",", "maxmess", ",", "maxr"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"rotcurve", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Cos", "[", "theta", "]"}], ",", 
             RowBox[{"-", 
              RowBox[{"Sin", "[", "theta", "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Sin", "[", "theta", "]"}], ",", " ", 
             RowBox[{"Cos", "[", "theta", "]"}]}], "}"}]}], "}"}], ".", " ", 
         RowBox[{"(", 
          RowBox[{"curve", "-", "pt"}], ")"}]}], "+", "pt"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"newcurve", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Cos", "[", "theta1", "]"}], ",", 
             RowBox[{"-", 
              RowBox[{"Sin", "[", "theta1", "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Sin", "[", "theta1", "]"}], ",", " ", 
             RowBox[{"Cos", "[", "theta1", "]"}]}], "}"}]}], "}"}], ".", " ", 
         
         RowBox[{"(", 
          RowBox[{"curve", "-", "pt"}], ")"}]}], "+", "pt"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"maxmess", "=", 
       RowBox[{"Norm", "[", 
        RowBox[{"curve", "-", "pt"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"maxr", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"FindMaximum", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"maxmess", ",", " ", 
             RowBox[{
             "tmin", "\[LessEqual]", " ", "t", " ", "\[LessEqual]", " ", 
              "tmax"}]}], "}"}], ",", "t"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "+", "1"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"xmax", "=", 
       RowBox[{
        RowBox[{"pt", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "+", "maxr"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"xmin", "=", 
       RowBox[{
        RowBox[{"pt", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "-", "maxr"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"ymax", "=", 
       RowBox[{
        RowBox[{"pt", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "+", "maxr"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"ymin", "=", 
       RowBox[{
        RowBox[{"pt", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "-", "maxr"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Return", "[", " ", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"ParametricPlot", "[", " ", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"curve", ",", "rotcurve"}], "}"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"t", ",", "tmin", ",", "tmax"}], "}"}]}], "]"}], ",", " ", 
         RowBox[{"Graphics", "[", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"PointSize", "[", ".03", "]"}], ",", " ", 
            RowBox[{"Point", "[", "pt", "]"}]}], "}"}], "]"}], ",", " ", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"xmin", ",", "xmax"}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"ymin", ",", "ymax"}], "}"}]}], "}"}]}], ",", " ", 
         RowBox[{"AxesOrigin", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}]}]}], "]"}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQ/Y39WbHRx5eOXOu7OkG0gClnH4iWmPKzH0S/lomc
AqJnmbWsBNEp64t3gOhrVtN3gejZae6HQHRRfOA9EO06P+YJiN4RuQlMz7rJ
/BJET1n/8R2Ilot58hWsv+gVmL648dpPEH2E3fwviF5zkYvFGEhPPDoNTAdu
vM4PoiNcGoVA9Dzxy8og+kVjhgqIfnDTyR1EO3GJRoHoJ3uZ4kD0tt03wHTY
HuUsEJ2nlw+m52V5FILolW1PwPSuAyplIHphlBeY9ptRVwuimZrlJ4DoLXWP
X4Polys/gWkAlMuoqA==
  "]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"DisplayRotatedCurve", "[", 
    RowBox[{"pt", ",", "z", ",", " ", 
     RowBox[{"{", 
      RowBox[{"curve1", ",", "curve2"}], "}"}], ",", "trange"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"curve1", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"4", "t"}], "]"}]}], "+", "2"}], ")"}], 
        RowBox[{"Cos", "[", "t", "]"}]}], "+", "5"}], ",", 
      "\"\<Parametric Curve X:\>\""}], "}"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"curve2", ",", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"4", "t"}], "]"}]}], "+", "2"}], ")"}], 
        RowBox[{"Sin", "[", "t", "]"}]}], "+", "12"}], ",", 
      "\"\<Parametric Curve Y:\>\""}], "}"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"trange", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"2", "Pi"}]}], "}"}], ",", "\"\<Range of t-values\>\""}], 
     "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"pt", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "4"}], ",", 
        RowBox[{"-", "9"}]}], "}"}], ",", "\"\<Center of Rotation\>\""}], 
     "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"z", ",", "0", ",", "\"\<Angle of Rotation\>\""}], "}"}], ",", 
     "0", ",", 
     RowBox[{"2", "Pi"}], ",", 
     RowBox[{"Pi", "/", "24"}]}], "}"}], ",", " ", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.481901318892655*^9, 3.4819013190910063`*^9}, {
  3.48190186837986*^9, 3.481901878690651*^9}, {3.481902230840909*^9, 
  3.481902232343268*^9}, {3.481902369012528*^9, 3.481902425426523*^9}, {
  3.481902490222761*^9, 3.481902492560047*^9}, {3.481902528125757*^9, 
  3.481902591492237*^9}, {3.481902642079011*^9, 3.481902861835742*^9}, {
  3.481902904012393*^9, 3.481902961899235*^9}, {3.481903212472476*^9, 
  3.4819032875133247`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`curve1$$ = 5 + 
    Cos[$CellContext`t] (2 + 3 Cos[4 $CellContext`t]), $CellContext`curve2$$ =
     12 + (2 + 3 Cos[4 $CellContext`t]) 
     Sin[$CellContext`t], $CellContext`pt$$ = {-4, -9}, $CellContext`trange$$ \
= {0, 2 Pi}, $CellContext`z$$ = 0, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`curve1$$], 5 + 
       Cos[$CellContext`t] (2 + 3 Cos[4 $CellContext`t]), 
       "Parametric Curve X:"}}, {{
       Hold[$CellContext`curve2$$], 
       12 + (2 + 3 Cos[4 $CellContext`t]) Sin[$CellContext`t], 
       "Parametric Curve Y:"}}, {{
       Hold[$CellContext`trange$$], {0, 2 Pi}, "Range of t-values"}}, {{
       Hold[$CellContext`pt$$], {-4, -9}, "Center of Rotation"}}, {{
       Hold[$CellContext`z$$], 0, "Angle of Rotation"}, 0, 2 Pi, 
      Rational[1, 24] Pi}}, Typeset`size$$ = {441., {217., 224.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`z$819432$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`curve1$$ = 
        5 + Cos[$CellContext`t] (2 + 
           3 Cos[4 $CellContext`t]), $CellContext`curve2$$ = 
        12 + (2 + 3 Cos[4 $CellContext`t]) 
          Sin[$CellContext`t], $CellContext`pt$$ = {-4, -9}, \
$CellContext`trange$$ = {0, 2 Pi}, $CellContext`z$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`z$$, $CellContext`z$819432$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`DisplayRotatedCurve[$CellContext`pt$$, \
$CellContext`z$$, {$CellContext`curve1$$, $CellContext`curve2$$}, \
$CellContext`trange$$], 
      "Specifications" :> {{{$CellContext`curve1$$, 5 + 
          Cos[$CellContext`t] (2 + 3 Cos[4 $CellContext`t]), 
          "Parametric Curve X:"}}, {{$CellContext`curve2$$, 
          12 + (2 + 3 Cos[4 $CellContext`t]) Sin[$CellContext`t], 
          "Parametric Curve Y:"}}, {{$CellContext`trange$$, {0, 2 Pi}, 
          "Range of t-values"}}, {{$CellContext`pt$$, {-4, -9}, 
          "Center of Rotation"}}, {{$CellContext`z$$, 0, "Angle of Rotation"},
          0, 2 Pi, Rational[1, 24] Pi}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{494., {333.21875, 339.78125}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`DisplayRotatedCurve[
         Pattern[$CellContext`pt, 
          Blank[]], 
         Pattern[$CellContext`theta, 
          Blank[]], 
         Pattern[$CellContext`curve, 
          Blank[]], {
          Pattern[$CellContext`tmin, 
           Blank[]], 
          Pattern[$CellContext`tmax, 
           Blank[]]}] := 
       Block[{$CellContext`newcurve, $CellContext`t, $CellContext`xmax, \
$CellContext`xmin, $CellContext`ymax, $CellContext`ymin, $CellContext`theta1, \
$CellContext`maxmess, $CellContext`maxr}, $CellContext`rotcurve = Dot[{{
               Cos[$CellContext`theta], -Sin[$CellContext`theta]}, {
               Sin[$CellContext`theta], 
               
               Cos[$CellContext`theta]}}, $CellContext`curve - \
$CellContext`pt] + $CellContext`pt; $CellContext`newcurve = Dot[{{
               Cos[$CellContext`theta1], -Sin[$CellContext`theta1]}, {
               Sin[$CellContext`theta1], 
               
               Cos[$CellContext`theta1]}}, $CellContext`curve - \
$CellContext`pt] + $CellContext`pt; $CellContext`maxmess = 
          Norm[$CellContext`curve - $CellContext`pt]; $CellContext`maxr = Part[
             
             FindMaximum[{$CellContext`maxmess, $CellContext`tmin <= \
$CellContext`t <= $CellContext`tmax}, $CellContext`t], 1] + 
           1; $CellContext`xmax = 
          Part[$CellContext`pt, 1] + $CellContext`maxr; $CellContext`xmin = 
          Part[$CellContext`pt, 1] - $CellContext`maxr; $CellContext`ymax = 
          Part[$CellContext`pt, 2] + $CellContext`maxr; $CellContext`ymin = 
          Part[$CellContext`pt, 2] - $CellContext`maxr; Return[
           Show[
            
            ParametricPlot[{$CellContext`curve, $CellContext`rotcurve}, \
{$CellContext`t, $CellContext`tmin, $CellContext`tmax}], 
            Graphics[{
              PointSize[0.03], 
              Point[$CellContext`pt]}], 
            PlotRange -> {{$CellContext`xmin, $CellContext`xmax}, \
{$CellContext`ymin, $CellContext`ymax}}, 
            AxesOrigin -> {0, 0}]]], $CellContext`rotcurve = {
        5 + Cos[$CellContext`t] (2 + 3 Cos[4 $CellContext`t]), 
         12 + (2 + 3 Cos[4 $CellContext`t]) Sin[$CellContext`t]}}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.481902703752778*^9, 3.481902731041613*^9}, 
   3.481902788065918*^9, {3.481902849191123*^9, 3.481902862167099*^9}, 
   3.481902914210635*^9, 3.4819029662646017`*^9, 3.481903224924389*^9, 
   3.481903288047373*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{640, 750},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 101, 1, 57, "Subtitle"],
Cell[671, 25, 559, 9, 107, "Text"],
Cell[1233, 36, 4409, 119, 23, "Input",
 CellOpen->False],
Cell[CellGroupData[{
Cell[5667, 159, 2251, 63, 23, "Input",
 CellOpen->False],
Cell[7921, 224, 5500, 109, 693, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
