(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     39581,        965]
NotebookOptionsPosition[     39009,        941]
NotebookOutlinePosition[     39351,        956]
CellTagsIndexPosition[     39308,        953]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Example 5.2.1", "Subtitle",
 CellChangeTimes->{{3.4851870005322857`*^9, 3.4851870038807783`*^9}, {
  3.491735014553479*^9, 3.491735015890952*^9}}],

Cell["\<\
This notebook contains a manipulation which illustrates Example 5.2.1 of the \
text.  This example illustrates the cofactor expansion of a matrix along any \
row or column (along with the resultant arithmetic if you want).  The \
computation is shown for a single level of recursion - that is, a 4\[Times]4 \
determinent is broken down into 4 3\[Times]3 determinants, which are then \
done immediately if you want to see the computation to its end.

The reason for only going down a single level is that in general an \
n\[Times]n determinant invovles breaking the computation into n! small \
determinants (where the \"small\" determinants are 1\[Times]1 determinants, \
which are easy).  As n grows, n! gets extremely large, which means the \
computations you would get would be too long to follow easily.

If you do want to see a computation done with all of its parts, you can use \
the second copy of the manipulation to break down any part further (below, \
the second copy of the manipulation shows how to break down the first 3\
\[Times]3 determinant in the original).\
\>", "Text",
 CellChangeTimes->{{3.4851870407705584`*^9, 3.4851871195926867`*^9}, {
  3.491735022227813*^9, 3.491735417835168*^9}, {3.491735476447115*^9, 
  3.491735527179463*^9}, {3.491735620811084*^9, 3.491735621140052*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DeletedMatrix", "[", 
     RowBox[{"mat_", ",", 
      RowBox[{"{", 
       RowBox[{"i_", ",", "j_"}], "}"}]}], "]"}], ":=", " ", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Drop", "[", " ", 
      RowBox[{
       RowBox[{"Transpose", "[", " ", 
        RowBox[{"Drop", "[", 
         RowBox[{"mat", ",", 
          RowBox[{"{", "i", "}"}]}], "]"}], "]"}], ",", 
       RowBox[{"{", "j", "}"}]}], "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"RowExpansion1", "[", 
     RowBox[{"mat_", ",", " ", "i_"}], "]"}], ":=", " ", 
    RowBox[{"Block", "[", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"n", ",", "j", ",", "row"}], "}"}], ",", "\[IndentingNewLine]",
       " ", 
      RowBox[{
       RowBox[{"n", "=", 
        RowBox[{"Length", "[", "mat", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"row", "=", 
        RowBox[{"Table", "[", " ", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Superscript", "[", 
             RowBox[{
              RowBox[{"-", "1"}], ",", " ", 
              RowBox[{"StringJoin", "[", 
               RowBox[{
                RowBox[{"ToString", "[", "i", "]"}], ",", "\"\<+\>\"", ",", 
                RowBox[{"ToString", "[", "j", "]"}]}], "]"}]}], "]"}], ",", 
            "\"\< \[Times] \>\"", ",", " ", 
            RowBox[{"mat", "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "j"}], "]"}], "]"}], ",", "  ", 
            "\"\< \[Times] \>\"", ",", "\"\<Det[\>\"", ",", 
            RowBox[{"MatrixForm", "[", 
             RowBox[{"DeletedMatrix", "[", 
              RowBox[{"mat", ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", "j"}], "}"}]}], "]"}], "]"}], ",", 
            "\"\<] + \>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "1", ",", "n"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Return", "[", " ", 
        RowBox[{"Row", "[", 
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"Delete", "[", 
            RowBox[{
             RowBox[{"Flatten", "[", "row", "]"}], ",", 
             RowBox[{"-", "1"}]}], "]"}], ",", 
           RowBox[{"{", "\"\<]\>\"", "}"}]}], " ", "]"}], "]"}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"RowExpansion2", "[", 
     RowBox[{"mat_", ",", " ", "i_"}], "]"}], ":=", " ", 
    RowBox[{"Block", "[", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"n", ",", "j", ",", "row"}], "}"}], ",", "\[IndentingNewLine]",
       " ", 
      RowBox[{
       RowBox[{"n", "=", 
        RowBox[{"Length", "[", "mat", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"row", "=", 
        RowBox[{"Table", "[", " ", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "^", 
             RowBox[{"(", 
              RowBox[{"i", "+", "j"}], ")"}]}], ",", "\"\< \[Times] \>\"", 
            ",", " ", 
            RowBox[{"mat", "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "j"}], "]"}], "]"}], ",", "  ", 
            "\"\< \[Times] \>\"", ",", 
            RowBox[{"Det", "[", 
             RowBox[{"DeletedMatrix", "[", 
              RowBox[{"mat", ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", "j"}], "}"}]}], "]"}], "]"}], ",", 
            "\"\< + \>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "1", ",", "n"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Return", "[", " ", 
        RowBox[{"Row", "[", 
         RowBox[{"Join", "[", " ", 
          RowBox[{
           RowBox[{"{", "\"\<= \>\"", "}"}], ",", 
           RowBox[{"Delete", "[", 
            RowBox[{
             RowBox[{"Flatten", "[", "row", "]"}], ",", 
             RowBox[{"-", "1"}]}], "]"}]}], "]"}], "]"}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"RowExpansion3", "[", 
     RowBox[{"mat_", ",", " ", "i_"}], "]"}], ":=", " ", 
    RowBox[{"Block", "[", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"n", ",", "j", ",", "row"}], "}"}], ",", "\[IndentingNewLine]",
       " ", 
      RowBox[{
       RowBox[{"n", "=", 
        RowBox[{"Length", "[", "mat", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"row", "=", 
        RowBox[{"Table", "[", " ", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "^", 
              RowBox[{"(", 
               RowBox[{"i", "+", "j"}], ")"}]}], " ", 
             RowBox[{"mat", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "j"}], "]"}], "]"}], 
             RowBox[{"Det", "[", 
              RowBox[{"DeletedMatrix", "[", 
               RowBox[{"mat", ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "j"}], "}"}]}], "]"}], "]"}]}], ",", 
            "\"\< + \>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "1", ",", "n"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Return", "[", " ", 
        RowBox[{"Row", "[", 
         RowBox[{"Join", "[", " ", 
          RowBox[{
           RowBox[{"{", "\"\<= \>\"", "}"}], ",", 
           RowBox[{"Delete", "[", 
            RowBox[{
             RowBox[{"Flatten", "[", "row", "]"}], ",", 
             RowBox[{"-", "1"}]}], "]"}]}], "]"}], "]"}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ColumnExpansion3", "[", 
     RowBox[{"mat_", ",", " ", "i_"}], "]"}], ":=", " ", 
    RowBox[{"Block", "[", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"n", ",", "j", ",", "row"}], "}"}], ",", "\[IndentingNewLine]",
       " ", 
      RowBox[{
       RowBox[{"n", "=", 
        RowBox[{"Length", "[", "mat", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"row", "=", 
        RowBox[{"Table", "[", " ", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"-", "1"}], ")"}], "^", 
              RowBox[{"(", 
               RowBox[{"i", "+", "j"}], ")"}]}], " ", 
             RowBox[{"mat", "[", 
              RowBox[{"[", 
               RowBox[{"j", ",", "i"}], "]"}], "]"}], 
             RowBox[{"Det", "[", 
              RowBox[{"DeletedMatrix", "[", 
               RowBox[{"mat", ",", 
                RowBox[{"{", 
                 RowBox[{"j", ",", "i"}], "}"}]}], "]"}], "]"}]}], ",", 
            "\"\< + \>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "1", ",", "n"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Return", "[", " ", 
        RowBox[{"Row", "[", 
         RowBox[{"Join", "[", " ", 
          RowBox[{
           RowBox[{"{", "\"\<= \>\"", "}"}], ",", 
           RowBox[{"Delete", "[", 
            RowBox[{
             RowBox[{"Flatten", "[", "row", "]"}], ",", 
             RowBox[{"-", "1"}]}], "]"}]}], "]"}], "]"}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ColumnExpansion1", "[", 
     RowBox[{"mat_", ",", " ", "i_"}], "]"}], ":=", " ", 
    RowBox[{"Block", "[", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"n", ",", "j", ",", "row"}], "}"}], ",", "\[IndentingNewLine]",
       " ", 
      RowBox[{
       RowBox[{"n", "=", 
        RowBox[{"Length", "[", "mat", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"row", "=", 
        RowBox[{"Table", "[", " ", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Superscript", "[", 
             RowBox[{
              RowBox[{"-", "1"}], ",", " ", 
              RowBox[{"StringJoin", "[", 
               RowBox[{
                RowBox[{"ToString", "[", "i", "]"}], ",", "\"\<+\>\"", ",", 
                RowBox[{"ToString", "[", "j", "]"}]}], "]"}]}], "]"}], ",", 
            "\"\< \[Times] \>\"", ",", " ", 
            RowBox[{"mat", "[", 
             RowBox[{"[", 
              RowBox[{"j", ",", "i"}], "]"}], "]"}], ",", "  ", 
            "\"\< \[Times] \>\"", ",", "\"\<Det[\>\"", ",", 
            RowBox[{"MatrixForm", "[", 
             RowBox[{"DeletedMatrix", "[", 
              RowBox[{"mat", ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", "i"}], "}"}]}], "]"}], "]"}], ",", 
            "\"\<] + \>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "1", ",", "n"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Return", "[", " ", 
        RowBox[{"Row", "[", 
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"Delete", "[", 
            RowBox[{
             RowBox[{"Flatten", "[", "row", "]"}], ",", 
             RowBox[{"-", "1"}]}], "]"}], ",", 
           RowBox[{"{", "\"\<]\>\"", "}"}]}], " ", "]"}], "]"}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ColumnExpansion2", "[", 
     RowBox[{"mat_", ",", " ", "i_"}], "]"}], ":=", " ", 
    RowBox[{"Block", "[", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"n", ",", "j", ",", "row"}], "}"}], ",", "\[IndentingNewLine]",
       " ", 
      RowBox[{
       RowBox[{"n", "=", 
        RowBox[{"Length", "[", "mat", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"row", "=", 
        RowBox[{"Table", "[", " ", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], "^", 
             RowBox[{"(", 
              RowBox[{"i", "+", "j"}], ")"}]}], ",", "\"\< \[Times] \>\"", 
            ",", " ", 
            RowBox[{"mat", "[", 
             RowBox[{"[", 
              RowBox[{"j", ",", "i"}], "]"}], "]"}], ",", "  ", 
            "\"\< \[Times] \>\"", ",", 
            RowBox[{"Det", "[", 
             RowBox[{"DeletedMatrix", "[", 
              RowBox[{"mat", ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", "i"}], "}"}]}], "]"}], "]"}], ",", 
            "\"\< + \>\""}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "1", ",", "n"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Return", "[", " ", 
        RowBox[{"Row", "[", 
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"{", "\"\<= \>\"", "}"}], ",", 
           RowBox[{"Delete", "[", 
            RowBox[{
             RowBox[{"Flatten", "[", "row", "]"}], ",", 
             RowBox[{"-", "1"}]}], "]"}]}], "]"}], "]"}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DetPresent", "[", 
   RowBox[{"m_", ",", " ", "rc_", ",", " ", "i_", ",", "expandflag_"}], "]"}],
   ":=", "\[IndentingNewLine]", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", "rawoutput", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Dimensions", "[", "m", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "\[NotEqual]", " ", 
        RowBox[{
         RowBox[{"Dimensions", "[", "m", "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ",", " ", 
       RowBox[{
       "Return", "[", 
        "\"\<The given matrix is not square, no determinant can be done. \
\>\"", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"!", 
         RowBox[{"IntegerQ", "[", "i", "]"}]}], "||", " ", 
        RowBox[{"i", "<", "1"}], "||", " ", 
        RowBox[{"i", ">", 
         RowBox[{"Length", "[", "m", "]"}]}]}], ",", " ", 
       RowBox[{"Return", "[", "\"\<Invalid row/column number\>\"", "]"}]}], 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"rawoutput", "=", 
      RowBox[{"Column", "[", " ", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Row", "[", " ", 
          RowBox[{"{", 
           RowBox[{"\"\<For the matrix \>\"", ",", " ", 
            RowBox[{"MatrixForm", "[", "m", "]"}], ",", " ", 
            "\"\< and an expansion along \>\"", ",", " ", 
            RowBox[{"If", "[", " ", 
             RowBox[{
              RowBox[{"rc", "\[Equal]", "1"}], ",", " ", "\"\<row \>\"", ",", 
              " ", "\"\<column \>\""}], "]"}], ",", " ", "i", ",", " ", 
            "\"\<, we have the determinant is\>\""}], "}"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"rc", "\[Equal]", "1"}], ",", " ", 
           RowBox[{"RowExpansion1", "[", 
            RowBox[{"m", ",", "i"}], "]"}], ",", 
           RowBox[{"ColumnExpansion1", "[", 
            RowBox[{"m", ",", "i"}], "]"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{"expandflag", ",", " ", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"rc", "\[Equal]", "1"}], ",", 
             RowBox[{"RowExpansion2", "[", 
              RowBox[{"m", ",", "i"}], "]"}], ",", 
             RowBox[{"ColumnExpansion2", "[", 
              RowBox[{"m", ",", "i"}], "]"}]}], "]"}], ",", "\"\< \>\""}], 
          "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{"expandflag", ",", " ", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"rc", "\[Equal]", "1"}], ",", 
             RowBox[{"RowExpansion3", "[", 
              RowBox[{"m", ",", "i"}], "]"}], ",", 
             RowBox[{"ColumnExpansion3", "[", 
              RowBox[{"m", ",", "i"}], "]"}]}], "]"}], ",", "\"\< \>\""}], 
          "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{"expandflag", ",", " ", 
           RowBox[{"Row", "[", " ", 
            RowBox[{"{", 
             RowBox[{"\"\<= \>\"", ",", 
              RowBox[{"Det", "[", "m", "]"}]}], "}"}], "]"}], ",", 
           "\"\< \>\""}], "]"}]}], "\[IndentingNewLine]", "}"}], "]"}]}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"Return", "[", "rawoutput", "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.491658877145509*^9, 3.4916590885904293`*^9}, {
   3.491659341305369*^9, 3.4916594022257147`*^9}, {3.491659432868271*^9, 
   3.491659500410741*^9}, {3.4916595386290073`*^9, 3.4916595757551737`*^9}, {
   3.491659673821505*^9, 3.491659678434445*^9}, {3.491659801670231*^9, 
   3.491659803732255*^9}, {3.491659890342381*^9, 3.491659970621272*^9}, {
   3.491660021975635*^9, 3.491660474187531*^9}, {3.49166056415486*^9, 
   3.491660640373838*^9}, 3.491660678624123*^9, {3.491660730518703*^9, 
   3.491660752504475*^9}, {3.491660805343607*^9, 3.491660857944139*^9}, {
   3.4916609026839523`*^9, 3.4916609411543207`*^9}, {3.4916610601479683`*^9, 
   3.491661499358787*^9}, {3.491661666832901*^9, 3.491661695285009*^9}, {
   3.491661745115899*^9, 3.4916617705032663`*^9}, {3.491661906753539*^9, 
   3.491661983976358*^9}, {3.491662069989872*^9, 3.491662130907899*^9}, {
   3.491663294955926*^9, 3.491663325556306*^9}, {3.491734164635337*^9, 
   3.4917342332123823`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Manipulate", "[", " ", 
   RowBox[{
    RowBox[{"DetPresent", "[", 
     RowBox[{"m", ",", "rc", ",", "p", ",", "expand"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"(", "\[NoBreak]", GridBox[{
           {
            RowBox[{"-", "9"}], "5", "0", "2"},
           {"4", 
            RowBox[{"-", "1"}], "3", "7"},
           {"6", 
            RowBox[{"-", "2"}], "0", 
            RowBox[{"-", "8"}]},
           {"1", "10", 
            RowBox[{"-", "4"}], "11"}
          }], "\[NoBreak]", ")"}], ",", " ", "\"\<Matrix\>\""}], "}"}], ",", 
      " ", 
      RowBox[{"ControlType", "\[Rule]", "InputField"}], ",", " ", 
      RowBox[{"FieldSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"12", ",", "5"}], "}"}]}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"rc", ",", "1", ",", "\"\<Row or column expansion \>\""}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", "\[Rule]", "\"\<Row\>\""}], ",", " ", 
        RowBox[{"2", "\[Rule]", "\"\<Column\>\""}]}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"p", ",", "1", ",", "\"\<Along row/column # \>\""}], "}"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "expand", ",", "False", ",", " ", 
        "\"\<Continue the computation? \>\""}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"True", ",", "False"}], "}"}]}], "}"}], ",", " ", 
    RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}], " "}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.491662866767633*^9, 3.491663031562316*^9}, {
  3.491663140494136*^9, 3.491663144267335*^9}, {3.4916632067814913`*^9, 
  3.491663245779024*^9}, {3.491663381789713*^9, 3.49166339590901*^9}, {
  3.4917343555057163`*^9, 3.491734462835064*^9}, {3.491734597200791*^9, 
  3.4917346032019587`*^9}, {3.49173480417206*^9, 3.491734840832982*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`expand$$ = False, $CellContext`m$$ = {{-9, 
    5, 0, 2}, {4, -1, 3, 7}, {6, -2, 0, -8}, {1, 10, -4, 
    11}}, $CellContext`p$$ = 1, $CellContext`rc$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`m$$], {{-9, 5, 0, 2}, {4, -1, 3, 7}, {6, -2, 
       0, -8}, {1, 10, -4, 11}}, "Matrix"}}, {{
       Hold[$CellContext`rc$$], 1, "Row or column expansion "}, {
      1 -> "Row", 2 -> "Column"}}, {{
       Hold[$CellContext`p$$], 1, "Along row/column # "}}, {{
       Hold[$CellContext`expand$$], False, "Continue the computation? "}, {
      True, False}}}, Typeset`size$$ = {441., {208.21875, 214.78125}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`rc$3408$$ = False, $CellContext`expand$3409$$ = 
    False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`expand$$ = 
        False, $CellContext`m$$ = {{-9, 5, 0, 2}, {4, -1, 3, 7}, {6, -2, 
         0, -8}, {1, 10, -4, 11}}, $CellContext`p$$ = 1, $CellContext`rc$$ = 
        1}, "ControllerVariables" :> {
        Hold[$CellContext`rc$$, $CellContext`rc$3408$$, False], 
        Hold[$CellContext`expand$$, $CellContext`expand$3409$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`DetPresent[$CellContext`m$$, $CellContext`rc$$, \
$CellContext`p$$, $CellContext`expand$$], 
      "Specifications" :> {{{$CellContext`m$$, {{-9, 5, 0, 2}, {4, -1, 3, 
          7}, {6, -2, 0, -8}, {1, 10, -4, 11}}, "Matrix"}, ControlType -> 
         InputField, 
         FieldSize -> {12, 5}}, {{$CellContext`rc$$, 1, 
          "Row or column expansion "}, {
         1 -> "Row", 2 -> "Column"}}, {{$CellContext`p$$, 1, 
          "Along row/column # "}}, {{$CellContext`expand$$, False, 
          "Continue the computation? "}, {True, False}}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{494., {347.21875, 353.78125}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`DetPresent[
         Pattern[$CellContext`m, 
          Blank[]], 
         Pattern[$CellContext`rc, 
          Blank[]], 
         Pattern[$CellContext`i, 
          Blank[]], 
         Pattern[$CellContext`expandflag, 
          Blank[]]] := Block[{$CellContext`rawoutput}, If[Part[
             Dimensions[$CellContext`m], 1] != Part[
             Dimensions[$CellContext`m], 2], 
           Return[
           "The given matrix is not square, no determinant can be done. "]]; 
         If[
           Or[
            Not[
             IntegerQ[$CellContext`i]], $CellContext`i < 1, $CellContext`i > 
            Length[$CellContext`m]], 
           Return["Invalid row/column number"]]; $CellContext`rawoutput = 
          Column[{
             Row[{"For the matrix ", 
               MatrixForm[$CellContext`m], " and an expansion along ", 
               If[$CellContext`rc == 1, "row ", "column "], $CellContext`i, 
               ", we have the determinant is"}], 
             If[$CellContext`rc == 1, 
              $CellContext`RowExpansion1[$CellContext`m, $CellContext`i], 
              $CellContext`ColumnExpansion1[$CellContext`m, $CellContext`i]], 
             
             If[$CellContext`expandflag, 
              If[$CellContext`rc == 1, 
               $CellContext`RowExpansion2[$CellContext`m, $CellContext`i], 
               $CellContext`ColumnExpansion2[$CellContext`m, $CellContext`i]],
               " "], 
             If[$CellContext`expandflag, 
              If[$CellContext`rc == 1, 
               $CellContext`RowExpansion3[$CellContext`m, $CellContext`i], 
               $CellContext`ColumnExpansion3[$CellContext`m, $CellContext`i]],
               " "], 
             If[$CellContext`expandflag, 
              Row[{"= ", 
                Det[$CellContext`m]}], " "]}]; 
         Return[$CellContext`rawoutput]], $CellContext`RowExpansion1[
         Pattern[$CellContext`mat, 
          Blank[]], 
         Pattern[$CellContext`i, 
          Blank[]]] := 
       Block[{$CellContext`n, $CellContext`j, $CellContext`row}, \
$CellContext`n = Length[$CellContext`mat]; $CellContext`row = Table[{
             Superscript[-1, 
              StringJoin[
               ToString[$CellContext`i], "+", 
               ToString[$CellContext`j]]], " \[Times] ", 
             Part[$CellContext`mat, $CellContext`i, $CellContext`j], 
             " \[Times] ", "Det[", 
             MatrixForm[
              $CellContext`DeletedMatrix[$CellContext`mat, {$CellContext`i, \
$CellContext`j}]], "] + "}, {$CellContext`j, 1, $CellContext`n}]; Return[
           Row[
            Join[
             Delete[
              Flatten[$CellContext`row], -1], {"]"}]]]], 
       Attributes[Superscript] = {
        NHoldRest, ReadProtected}, $CellContext`DeletedMatrix[
         Pattern[$CellContext`mat, 
          Blank[]], {
          Pattern[$CellContext`i, 
           Blank[]], 
          Pattern[$CellContext`j, 
           Blank[]]}] := Transpose[
         Drop[
          Transpose[
           
           Drop[$CellContext`mat, {$CellContext`i}]], {$CellContext`j}]], \
$CellContext`ColumnExpansion1[
         Pattern[$CellContext`mat, 
          Blank[]], 
         Pattern[$CellContext`i, 
          Blank[]]] := 
       Block[{$CellContext`n, $CellContext`j, $CellContext`row}, \
$CellContext`n = Length[$CellContext`mat]; $CellContext`row = Table[{
             Superscript[-1, 
              StringJoin[
               ToString[$CellContext`i], "+", 
               ToString[$CellContext`j]]], " \[Times] ", 
             Part[$CellContext`mat, $CellContext`j, $CellContext`i], 
             " \[Times] ", "Det[", 
             MatrixForm[
              $CellContext`DeletedMatrix[$CellContext`mat, {$CellContext`j, \
$CellContext`i}]], "] + "}, {$CellContext`j, 1, $CellContext`n}]; Return[
           Row[
            Join[
             Delete[
              Flatten[$CellContext`row], -1], {
             "]"}]]]], $CellContext`RowExpansion2[
         Pattern[$CellContext`mat, 
          Blank[]], 
         Pattern[$CellContext`i, 
          Blank[]]] := 
       Block[{$CellContext`n, $CellContext`j, $CellContext`row}, \
$CellContext`n = Length[$CellContext`mat]; $CellContext`row = 
          Table[{(-1)^($CellContext`i + $CellContext`j), " \[Times] ", 
             Part[$CellContext`mat, $CellContext`i, $CellContext`j], 
             " \[Times] ", 
             Det[
              $CellContext`DeletedMatrix[$CellContext`mat, {$CellContext`i, \
$CellContext`j}]], " + "}, {$CellContext`j, 1, $CellContext`n}]; Return[
           Row[
            Join[{"= "}, 
             Delete[
              
              Flatten[$CellContext`row], -1]]]]], \
$CellContext`ColumnExpansion2[
         Pattern[$CellContext`mat, 
          Blank[]], 
         Pattern[$CellContext`i, 
          Blank[]]] := 
       Block[{$CellContext`n, $CellContext`j, $CellContext`row}, \
$CellContext`n = Length[$CellContext`mat]; $CellContext`row = 
          Table[{(-1)^($CellContext`i + $CellContext`j), " \[Times] ", 
             Part[$CellContext`mat, $CellContext`j, $CellContext`i], 
             " \[Times] ", 
             Det[
              $CellContext`DeletedMatrix[$CellContext`mat, {$CellContext`j, \
$CellContext`i}]], " + "}, {$CellContext`j, 1, $CellContext`n}]; Return[
           Row[
            Join[{"= "}, 
             Delete[
              Flatten[$CellContext`row], -1]]]]], $CellContext`RowExpansion3[
         Pattern[$CellContext`mat, 
          Blank[]], 
         Pattern[$CellContext`i, 
          Blank[]]] := 
       Block[{$CellContext`n, $CellContext`j, $CellContext`row}, \
$CellContext`n = Length[$CellContext`mat]; $CellContext`row = 
          Table[{(-1)^($CellContext`i + $CellContext`j) 
             Part[$CellContext`mat, $CellContext`i, $CellContext`j] Det[
               $CellContext`DeletedMatrix[$CellContext`mat, {$CellContext`i, \
$CellContext`j}]], " + "}, {$CellContext`j, 1, $CellContext`n}]; Return[
           Row[
            Join[{"= "}, 
             Delete[
              
              Flatten[$CellContext`row], -1]]]]], \
$CellContext`ColumnExpansion3[
         Pattern[$CellContext`mat, 
          Blank[]], 
         Pattern[$CellContext`i, 
          Blank[]]] := 
       Block[{$CellContext`n, $CellContext`j, $CellContext`row}, \
$CellContext`n = Length[$CellContext`mat]; $CellContext`row = 
          Table[{(-1)^($CellContext`i + $CellContext`j) 
             Part[$CellContext`mat, $CellContext`j, $CellContext`i] Det[
               $CellContext`DeletedMatrix[$CellContext`mat, {$CellContext`j, \
$CellContext`i}]], " + "}, {$CellContext`j, 1, $CellContext`n}]; Return[
           Row[
            Join[{"= "}, 
             Delete[
              Flatten[$CellContext`row], -1]]]]]}; Typeset`initDone$$ = True),
    
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Input"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`expand$$ = True, $CellContext`m$$ = {{-1, 3,
     7}, {-2, 0, -8}, {10, -4, 11}}, $CellContext`p$$ = 1, $CellContext`rc$$ =
     1, Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`m$$], {{-9, 5, 0, 2}, {4, -1, 3, 7}, {6, -2, 
       0, -8}, {1, 10, -4, 11}}, "Matrix"}}, {{
       Hold[$CellContext`rc$$], 1, "Row or column expansion "}, {
      1 -> "Row", 2 -> "Column"}}, {{
       Hold[$CellContext`p$$], 1, "Along row/column # "}}, {{
       Hold[$CellContext`expand$$], False, "Continue the computation? "}, {
      True, False}}}, Typeset`size$$ = {441., {111.71875, 118.28125}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`rc$3502$$ = False, $CellContext`expand$3503$$ = 
    False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`expand$$ = 
        False, $CellContext`m$$ = {{-9, 5, 0, 2}, {4, -1, 3, 7}, {6, -2, 
         0, -8}, {1, 10, -4, 11}}, $CellContext`p$$ = 1, $CellContext`rc$$ = 
        1}, "ControllerVariables" :> {
        Hold[$CellContext`rc$$, $CellContext`rc$3502$$, False], 
        Hold[$CellContext`expand$$, $CellContext`expand$3503$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`DetPresent[$CellContext`m$$, $CellContext`rc$$, \
$CellContext`p$$, $CellContext`expand$$], 
      "Specifications" :> {{{$CellContext`m$$, {{-9, 5, 0, 2}, {4, -1, 3, 
          7}, {6, -2, 0, -8}, {1, 10, -4, 11}}, "Matrix"}, ControlType -> 
         InputField, 
         FieldSize -> {12, 5}}, {{$CellContext`rc$$, 1, 
          "Row or column expansion "}, {
         1 -> "Row", 2 -> "Column"}}, {{$CellContext`p$$, 1, 
          "Along row/column # "}}, {{$CellContext`expand$$, False, 
          "Continue the computation? "}, {True, False}}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{494., {250.21875, 256.78125}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`DetPresent[
         Pattern[$CellContext`m, 
          Blank[]], 
         Pattern[$CellContext`rc, 
          Blank[]], 
         Pattern[$CellContext`i, 
          Blank[]], 
         Pattern[$CellContext`expandflag, 
          Blank[]]] := Block[{$CellContext`rawoutput}, If[Part[
             Dimensions[$CellContext`m], 1] != Part[
             Dimensions[$CellContext`m], 2], 
           Return[
           "The given matrix is not square, no determinant can be done. "]]; 
         If[
           Or[
            Not[
             IntegerQ[$CellContext`i]], $CellContext`i < 1, $CellContext`i > 
            Length[$CellContext`m]], 
           Return["Invalid row/column number"]]; $CellContext`rawoutput = 
          Column[{
             Row[{"For the matrix ", 
               MatrixForm[$CellContext`m], " and an expansion along ", 
               If[$CellContext`rc == 1, "row ", "column "], $CellContext`i, 
               ", we have the determinant is"}], 
             If[$CellContext`rc == 1, 
              $CellContext`RowExpansion1[$CellContext`m, $CellContext`i], 
              $CellContext`ColumnExpansion1[$CellContext`m, $CellContext`i]], 
             
             If[$CellContext`expandflag, 
              If[$CellContext`rc == 1, 
               $CellContext`RowExpansion2[$CellContext`m, $CellContext`i], 
               $CellContext`ColumnExpansion2[$CellContext`m, $CellContext`i]],
               " "], 
             If[$CellContext`expandflag, 
              If[$CellContext`rc == 1, 
               $CellContext`RowExpansion3[$CellContext`m, $CellContext`i], 
               $CellContext`ColumnExpansion3[$CellContext`m, $CellContext`i]],
               " "], 
             If[$CellContext`expandflag, 
              Row[{"= ", 
                Det[$CellContext`m]}], " "]}]; 
         Return[$CellContext`rawoutput]], $CellContext`RowExpansion1[
         Pattern[$CellContext`mat, 
          Blank[]], 
         Pattern[$CellContext`i, 
          Blank[]]] := 
       Block[{$CellContext`n, $CellContext`j, $CellContext`row}, \
$CellContext`n = Length[$CellContext`mat]; $CellContext`row = Table[{
             Superscript[-1, 
              StringJoin[
               ToString[$CellContext`i], "+", 
               ToString[$CellContext`j]]], " \[Times] ", 
             Part[$CellContext`mat, $CellContext`i, $CellContext`j], 
             " \[Times] ", "Det[", 
             MatrixForm[
              $CellContext`DeletedMatrix[$CellContext`mat, {$CellContext`i, \
$CellContext`j}]], "] + "}, {$CellContext`j, 1, $CellContext`n}]; Return[
           Row[
            Join[
             Delete[
              Flatten[$CellContext`row], -1], {"]"}]]]], 
       Attributes[Superscript] = {
        NHoldRest, ReadProtected}, $CellContext`DeletedMatrix[
         Pattern[$CellContext`mat, 
          Blank[]], {
          Pattern[$CellContext`i, 
           Blank[]], 
          Pattern[$CellContext`j, 
           Blank[]]}] := Transpose[
         Drop[
          Transpose[
           
           Drop[$CellContext`mat, {$CellContext`i}]], {$CellContext`j}]], \
$CellContext`ColumnExpansion1[
         Pattern[$CellContext`mat, 
          Blank[]], 
         Pattern[$CellContext`i, 
          Blank[]]] := 
       Block[{$CellContext`n, $CellContext`j, $CellContext`row}, \
$CellContext`n = Length[$CellContext`mat]; $CellContext`row = Table[{
             Superscript[-1, 
              StringJoin[
               ToString[$CellContext`i], "+", 
               ToString[$CellContext`j]]], " \[Times] ", 
             Part[$CellContext`mat, $CellContext`j, $CellContext`i], 
             " \[Times] ", "Det[", 
             MatrixForm[
              $CellContext`DeletedMatrix[$CellContext`mat, {$CellContext`j, \
$CellContext`i}]], "] + "}, {$CellContext`j, 1, $CellContext`n}]; Return[
           Row[
            Join[
             Delete[
              Flatten[$CellContext`row], -1], {
             "]"}]]]], $CellContext`RowExpansion2[
         Pattern[$CellContext`mat, 
          Blank[]], 
         Pattern[$CellContext`i, 
          Blank[]]] := 
       Block[{$CellContext`n, $CellContext`j, $CellContext`row}, \
$CellContext`n = Length[$CellContext`mat]; $CellContext`row = 
          Table[{(-1)^($CellContext`i + $CellContext`j), " \[Times] ", 
             Part[$CellContext`mat, $CellContext`i, $CellContext`j], 
             " \[Times] ", 
             Det[
              $CellContext`DeletedMatrix[$CellContext`mat, {$CellContext`i, \
$CellContext`j}]], " + "}, {$CellContext`j, 1, $CellContext`n}]; Return[
           Row[
            Join[{"= "}, 
             Delete[
              
              Flatten[$CellContext`row], -1]]]]], \
$CellContext`ColumnExpansion2[
         Pattern[$CellContext`mat, 
          Blank[]], 
         Pattern[$CellContext`i, 
          Blank[]]] := 
       Block[{$CellContext`n, $CellContext`j, $CellContext`row}, \
$CellContext`n = Length[$CellContext`mat]; $CellContext`row = 
          Table[{(-1)^($CellContext`i + $CellContext`j), " \[Times] ", 
             Part[$CellContext`mat, $CellContext`j, $CellContext`i], 
             " \[Times] ", 
             Det[
              $CellContext`DeletedMatrix[$CellContext`mat, {$CellContext`j, \
$CellContext`i}]], " + "}, {$CellContext`j, 1, $CellContext`n}]; Return[
           Row[
            Join[{"= "}, 
             Delete[
              Flatten[$CellContext`row], -1]]]]], $CellContext`RowExpansion3[
         Pattern[$CellContext`mat, 
          Blank[]], 
         Pattern[$CellContext`i, 
          Blank[]]] := 
       Block[{$CellContext`n, $CellContext`j, $CellContext`row}, \
$CellContext`n = Length[$CellContext`mat]; $CellContext`row = 
          Table[{(-1)^($CellContext`i + $CellContext`j) 
             Part[$CellContext`mat, $CellContext`i, $CellContext`j] Det[
               $CellContext`DeletedMatrix[$CellContext`mat, {$CellContext`i, \
$CellContext`j}]], " + "}, {$CellContext`j, 1, $CellContext`n}]; Return[
           Row[
            Join[{"= "}, 
             Delete[
              
              Flatten[$CellContext`row], -1]]]]], \
$CellContext`ColumnExpansion3[
         Pattern[$CellContext`mat, 
          Blank[]], 
         Pattern[$CellContext`i, 
          Blank[]]] := 
       Block[{$CellContext`n, $CellContext`j, $CellContext`row}, \
$CellContext`n = Length[$CellContext`mat]; $CellContext`row = 
          Table[{(-1)^($CellContext`i + $CellContext`j) 
             Part[$CellContext`mat, $CellContext`j, $CellContext`i] Det[
               $CellContext`DeletedMatrix[$CellContext`mat, {$CellContext`j, \
$CellContext`i}]], " + "}, {$CellContext`j, 1, $CellContext`n}]; Return[
           Row[
            Join[{"= "}, 
             Delete[
              Flatten[$CellContext`row], -1]]]]]}; Typeset`initDone$$ = True),
    
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.49173542759578*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{640, 750},
WindowMargins->{{Automatic, 408}, {105, Automatic}},
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 152, 2, 57, "Subtitle"],
Cell[722, 26, 1313, 21, 314, "Text"],
Cell[2038, 49, 15722, 405, 23, "Input",
 CellOpen->False],
Cell[17763, 456, 2012, 53, 23, "Input",
 CellOpen->False],
Cell[CellGroupData[{
Cell[19800, 513, 9583, 211, 721, InheritFromParent],
Cell[29386, 726, 9595, 211, 527, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
