(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     24217,        604]
NotebookOptionsPosition[     23547,        575]
NotebookOutlinePosition[     23908,        591]
CellTagsIndexPosition[     23865,        588]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Example 6.2.2", "Subtitle",
 CellChangeTimes->{{3.481984575844379*^9, 3.481984577698741*^9}}],

Cell[TextData[{
 "This notebook contains manipulations for Example 6.2.2 of the text, which \
details how to find the area of a tringle in terms of the vectors which are \
two sides.  We assume that the 2 vectors ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["v", "\[RightVector]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["w", "\[RightVector]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " start at the origin so that the third side is given by the vector v-w. The \
formula for the area is then ",
 Cell[BoxData[
  FormBox[
   RowBox[{"A", "=", 
    SqrtBox[
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"|", 
          OverscriptBox["v", "\[RightVector]"], "|"}], ")"}], "2"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"|", 
          OverscriptBox["w", "\[RightVector]"], "|"}], ")"}], "2"]}], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         OverscriptBox["v", "\[RightVector]"], "\[CenterDot]", 
         OverscriptBox["w", "\[RightVector]"]}], ")"}], "2"]}]]}], 
   TraditionalForm]],
  FormatType->"TraditionalForm"],
 ".\n\nIn the first manipulation you may drag the vectors ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["v", "\[RightVector]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["w", "\[RightVector]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " about by moving their heads.  In the second, you may enter in precise \
coordinates for the heads of the vectors."
}], "Text",
 CellChangeTimes->{{3.48198459136312*^9, 3.481984835401622*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TriangleDiagram", "[", " ", 
   RowBox[{"pt1_", ",", " ", "pt2_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Block", "[", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "proj", ",", "norm1", ",", "norm2", ",", " ", "dotproduct", ",", "angle",
       ",", "graphics", ",", "height", ",", "v", ",", "w", ",", "i"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"norm1", "=", 
      RowBox[{"Norm", "[", "pt1", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"norm2", "=", 
      RowBox[{"Norm", "[", "pt2", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"proj", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"pt1", ".", "pt2"}], ")"}], "/", 
        RowBox[{"norm2", "^", "2"}]}], " ", "pt2"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"dotproduct", "=", 
      RowBox[{"pt1", ".", "pt2"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"height", "=", 
      RowBox[{"Norm", "[", " ", 
       RowBox[{"pt1", "-", "proj"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"angle", "=", " ", 
      RowBox[{
       RowBox[{"180.", "/", "Pi"}], " ", 
       RowBox[{"ArcCos", "[", " ", 
        RowBox[{
         RowBox[{"pt1", ".", "pt2"}], "/", 
         RowBox[{"(", 
          RowBox[{"norm1", " ", "norm2"}], ")"}]}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"graphics", "=", 
      RowBox[{"{", 
       RowBox[{"Red", ",", " ", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", " ", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", " ", "pt1"}], "}"}], "]"}], 
        ",", " ", "Green", ",", " ", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", " ", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", " ", "pt2"}], "}"}], "]"}], 
        ",", "Blue", ",", " ", 
        RowBox[{"Arrow", "[", " ", 
         RowBox[{"{", " ", 
          RowBox[{"pt2", ",", " ", "pt1"}], "}"}], "]"}], ",", " ", "Black", 
        ",", 
        RowBox[{"Line", "[", " ", 
         RowBox[{"{", 
          RowBox[{"proj", ",", " ", "pt1"}], "}"}], "]"}], ",", " ", 
        RowBox[{"Text", "[", " ", 
         RowBox[{
         "\"\<\!\(\*OverscriptBox[\(v\), \(\[RightVector]\)]\)\>\"", ",", 
          RowBox[{"pt1", "/", "2"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1.5"}], "}"}]}], "]"}], ",", " ", 
        RowBox[{"Text", "[", " ", 
         RowBox[{"\"\<\[Theta]\>\"", ",", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"pt1", "+", "pt2"}], ")"}], "/", 
            RowBox[{"Norm", "[", 
             RowBox[{"pt1", "+", "pt2"}], "]"}]}], "*", 
           RowBox[{"1", "/", "2"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
        " ", 
        RowBox[{"Text", "[", " ", 
         RowBox[{
         "\"\<\!\(\*OverscriptBox[\(w\), \(\[RightVector]\)]\)\>\"", ",", 
          RowBox[{"pt2", "/", "2"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1.5"}], "}"}]}], "]"}], ",", " ", 
        RowBox[{"Text", "[", " ", 
         RowBox[{
         "\"\<\!\(\*OverscriptBox[\(v\), \
\(\[RightVector]\)]\)-\!\(\*OverscriptBox[\(w\), \(\[RightVector]\)]\)\>\"", 
          ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"pt1", "+", "pt2"}], ")"}], "/", "2"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1.5"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<H\>\"", ",", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"proj", "+", "pt1"}], ")"}], "/", "2"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Return", "[", 
      RowBox[{"Column", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Show", "[", " ", 
          RowBox[{
           RowBox[{"Graphics", "[", "graphics", "]"}], ",", " ", 
           RowBox[{"ImageSize", "\[Rule]", "300"}], ",", " ", 
           RowBox[{"Axes", "\[Rule]", "True"}], ",", " ", 
           RowBox[{"Ticks", "\[Rule]", 
            RowBox[{"{", " ", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{"i", ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", 
                  RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "]"}], ",", 
              RowBox[{"Table", "[", 
               RowBox[{"i", ",", 
                RowBox[{"{", 
                 RowBox[{"i", ",", 
                  RowBox[{"-", "5"}], ",", "15"}], "}"}]}], "]"}]}], "}"}]}], 
           ",", " ", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "}"}]}]}], "]"}], 
         ",", " ", 
         RowBox[{"Row", "[", 
          RowBox[{"{", 
           RowBox[{
           "\"\<\!\(\*OverscriptBox[\(v\), \(\[RightVector]\)]\) is the \
vector \>\"", ",", "pt1"}], "}"}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Row", "[", 
          RowBox[{"{", 
           RowBox[{
           "\"\<\!\(\*OverscriptBox[\(w\), \(\[RightVector]\)]\) is the \
vector \>\"", ",", "pt2"}], "}"}], "]"}], ",", 
         RowBox[{"Row", "[", 
          RowBox[{"{", 
           RowBox[{
           "\"\<The norm of \!\(\*OverscriptBox[\(v\), \(\[RightVector]\)]\) \
is \>\"", ",", 
            RowBox[{"Norm", "[", "pt1", "]"}]}], "}"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Row", "[", 
          RowBox[{"{", 
           RowBox[{
           "\"\<The norm of \!\(\*OverscriptBox[\(w\), \(\[RightVector]\)]\) \
is \>\"", ",", 
            RowBox[{"Norm", "[", "pt2", "]"}]}], "}"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Row", "[", 
          RowBox[{"{", 
           RowBox[{
           "\"\<The dot product of \!\(\*OverscriptBox[\(v\), \
\(\[RightVector]\)]\) and \!\(\*OverscriptBox[\(w\), \(\[RightVector]\)]\) is \
\>\"", ",", "dotproduct"}], "}"}], "]"}], ",", 
         RowBox[{"Row", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<The area is\>\"", ",", "  ", 
            RowBox[{"\[Sqrt]", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 RowBox[{"TraditionalForm", "[", 
                  RowBox[{"Norm", "[", 
                   OverscriptBox["v", "\[RightVector]"], "]"}], "]"}], "2"], 
                " ", 
                SuperscriptBox[
                 RowBox[{"TraditionalForm", "[", 
                  RowBox[{"Norm", "[", 
                   OverscriptBox["w", "\[RightVector]"], "]"}], "]"}], "2"]}],
                "-", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  OverscriptBox["v", "\[RightVector]"], "\[CenterDot]", 
                  OverscriptBox["w", "\[RightVector]"]}], ")"}], "2"]}], 
              ")"}]}], ",", "\"\< = \>\"", ",", 
            RowBox[{"Sqrt", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Norm", "[", "pt1", "]"}], "^", "2"}], 
               RowBox[{
                RowBox[{"Norm", "[", "pt2", "]"}], "^", "2"}]}], "-", 
              RowBox[{"dotproduct", "^", "2"}]}], "]"}]}], "}"}], "]"}]}], 
        "}"}], "]"}], "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]",
    "]"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGCQAGIQbfpA1DPs40vHu+I6dSC6fM+CVhCts7OnD0QHnSr/
FwmkVxV3s0QB6USzuxwg+vjxe2D6w8F7PCB6y6lHfCDaSeqKEIieueqtOIjm
f9wuD6LNNn9VBNH/Ln6rA9FnLNY0gM07srIFRM/YEjUVRHcVqc8D0U/m2F0E
0c0qttdA9ImXnLdA9A6Dmw9A9Luba5+A6ANrVN6CaEHNMx9B9K45fN9BdETD
/18g2qD1AFM0kL53PJ4FRJe9Z+IC0eEqD6RB9D/jLTNBtNnZHWDaUIxhEYh+
pii7BESXe3utBNFs7G/AtEi0/24Q/cpRfD+IdhOedRhE8+w+A6bP/TjzBkR7
tkR+ANGp2+Z/Beu3ePgTRNcutPgPMT+bLQZIAwA2Mtyd
  "]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"TriangleDiagram", "[", 
    RowBox[{"p1", ",", "p2"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "4"}], "}"}]}], "}"}], ",", "Locator", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "None"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p2", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4"}], "}"}]}], "}"}], ",", "Locator", ",", " ", 
     RowBox[{"Appearance", "\[Rule]", "None"}]}], "}"}], ",", " ", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.4819736367002373`*^9, 3.4819736440210457`*^9}, {
   3.4819840627518797`*^9, 3.481984109423675*^9}, {3.481984182426405*^9, 
   3.48198419308039*^9}, 3.481984316195953*^9, {3.481984379820705*^9, 
   3.481984386859099*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`p1$$ = {1, 4}, $CellContext`p2$$ = {4, 4}, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`p1$$], {1, 4}}, Automatic}, {{
       Hold[$CellContext`p2$$], {4, 4}}, Automatic}}, Typeset`size$$ = {
    375., {266.21875, 272.78125}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`p1$$ = {1, 4}, $CellContext`p2$$ = {4, 4}},
       "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`TriangleDiagram[$CellContext`p1$$, \
$CellContext`p2$$], 
      "Specifications" :> {{{$CellContext`p1$$, {1, 4}}, Automatic, 
         ControlType -> Locator, Appearance -> 
         None}, {{$CellContext`p2$$, {4, 4}}, Automatic, ControlType -> 
         Locator, Appearance -> None}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{436., {305.21875, 311.78125}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`TriangleDiagram[
         Pattern[$CellContext`pt1, 
          Blank[]], 
         Pattern[$CellContext`pt2, 
          Blank[]]] := 
       Block[{$CellContext`proj, $CellContext`norm1, $CellContext`norm2, \
$CellContext`dotproduct, $CellContext`angle, $CellContext`graphics, \
$CellContext`height, $CellContext`v, $CellContext`w, $CellContext`i}, \
$CellContext`norm1 = Norm[$CellContext`pt1]; $CellContext`norm2 = 
          Norm[$CellContext`pt2]; $CellContext`proj = (
            
            Dot[$CellContext`pt1, $CellContext`pt2]/$CellContext`norm2^2) \
$CellContext`pt2; $CellContext`dotproduct = 
          Dot[$CellContext`pt1, $CellContext`pt2]; $CellContext`height = 
          Norm[$CellContext`pt1 - $CellContext`proj]; $CellContext`angle = (
            180./Pi) 
           ArcCos[Dot[$CellContext`pt1, $CellContext`pt2]/($CellContext`norm1 \
$CellContext`norm2)]; $CellContext`graphics = {Red, 
            Arrow[{{0, 0}, $CellContext`pt1}], Green, 
            Arrow[{{0, 0}, $CellContext`pt2}], Blue, 
            Arrow[{$CellContext`pt2, $CellContext`pt1}], Black, 
            Line[{$CellContext`proj, $CellContext`pt1}], 
            Text[
            "\!\(\*OverscriptBox[\(v\), \(\[RightVector]\)]\)", \
$CellContext`pt1/2, {0, 1.5}], 
            Text[
            "\[Theta]", (($CellContext`pt1 + $CellContext`pt2)/
              Norm[$CellContext`pt1 + $CellContext`pt2]) (1/2)], 
            Text[
            "\!\(\*OverscriptBox[\(w\), \(\[RightVector]\)]\)", \
$CellContext`pt2/2, {0, 1.5}], 
            Text[
            "\!\(\*OverscriptBox[\(v\), \
\(\[RightVector]\)]\)-\!\(\*OverscriptBox[\(w\), \(\[RightVector]\)]\)", \
($CellContext`pt1 + $CellContext`pt2)/2, {0, -1.5}], 
            Text["H", ($CellContext`proj + $CellContext`pt1)/2, {0, -1}]}; 
         Return[
           Row[{
             Show[
              Graphics[$CellContext`graphics], ImageSize -> 300, Axes -> True,
               Ticks -> {
                Table[$CellContext`i, {$CellContext`i, -5, 5}], 
                Table[$CellContext`i, {$CellContext`i, -5, 15}]}, 
              PlotRange -> {{-5, 5}, {-5, 5}}], 
             
             Row[{"\!\(\*OverscriptBox[\(v\), \(\[RightVector]\)]\) is the \
vector ", $CellContext`pt1}], 
             
             Row[{"\!\(\*OverscriptBox[\(w\), \(\[RightVector]\)]\) is the \
vector ", $CellContext`pt2}], 
             
             Row[{"The norm of \!\(\*OverscriptBox[\(v\), \(\[RightVector]\)]\
\) is ", 
               Norm[$CellContext`pt1]}], 
             
             Row[{"The norm of \!\(\*OverscriptBox[\(w\), \(\[RightVector]\)]\
\) is ", 
               Norm[$CellContext`pt2]}], 
             
             Row[{"The dot product of \!\(\*OverscriptBox[\(v\), \(\
\[RightVector]\)]\) and \!\(\*OverscriptBox[\(w\), \(\[RightVector]\)]\) is \
", $CellContext`dotproduct}], 
             Row[{"The area is", 
               DisplayForm[
                Sqrt[
                OverVector[$CellContext`v]^2 OverVector[$CellContext`w]^2 - 
                 CenterDot[
                   OverVector[$CellContext`v], 
                   OverVector[$CellContext`w]]^2]], " = ", 
               Sqrt[
               Norm[$CellContext`pt1]^2 
                 Norm[$CellContext`pt2]^2 - $CellContext`dotproduct^2]}]}]]]}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.481973644505796*^9, 3.4819736711304197`*^9}, {
   3.4819737256856737`*^9, 3.481973747392557*^9}, 3.481973814024748*^9, {
   3.481973844553735*^9, 3.481973878650218*^9}, {3.481980952871435*^9, 
   3.481980965537562*^9}, 3.481981000763796*^9, {3.4819810363872337`*^9, 
   3.481981048853878*^9}, {3.4819811133122597`*^9, 3.481981121064343*^9}, 
   3.481981990680086*^9, {3.481982022961529*^9, 3.481982049497238*^9}, 
   3.4819820998805513`*^9, 3.4819821336078*^9, {3.481982196023436*^9, 
   3.4819822110992193`*^9}, 3.481982243271562*^9, 3.4819822899182997`*^9, {
   3.4819826492584352`*^9, 3.481982674158456*^9}, 3.4819827664385157`*^9, {
   3.481982840625949*^9, 3.481982866604526*^9}, 3.481982938150566*^9, {
   3.481983002193375*^9, 3.4819830124529953`*^9}, {3.4819831260647984`*^9, 
   3.4819831519437428`*^9}, 3.481983185908684*^9, 3.481984111691305*^9, 
   3.4819842146750298`*^9, {3.481984292180591*^9, 3.481984341151239*^9}, 
   3.4819843930264053`*^9, 3.481984517362279*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"TriangleDiagram", "[", 
    RowBox[{"p1", ",", "p2"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"p1", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "4"}], "}"}], ",", "\"\<The vector v\>\""}], "}"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"p2", ",", 
      RowBox[{"{", 
       RowBox[{"4", ",", "4"}], "}"}], ",", "\"\<The vector v\>\""}], "}"}], 
    "}"}], ",", " ", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.481984412909253*^9, 3.481984453612389*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`p1$$ = {1, 4}, $CellContext`p2$$ = {4, 4}, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`p1$$], {1, 4}, "The vector v"}}, {{
       Hold[$CellContext`p2$$], {4, 4}, "The vector v"}}}, Typeset`size$$ = {
    375., {266.21875, 272.78125}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`p1$$ = {1, 4}, $CellContext`p2$$ = {4, 4}},
       "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`TriangleDiagram[$CellContext`p1$$, \
$CellContext`p2$$], 
      "Specifications" :> {{{$CellContext`p1$$, {1, 4}, 
          "The vector v"}}, {{$CellContext`p2$$, {4, 4}, "The vector v"}}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{428., {334.21875, 340.78125}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`TriangleDiagram[
         Pattern[$CellContext`pt1, 
          Blank[]], 
         Pattern[$CellContext`pt2, 
          Blank[]]] := 
       Block[{$CellContext`proj, $CellContext`norm1, $CellContext`norm2, \
$CellContext`dotproduct, $CellContext`angle, $CellContext`graphics, \
$CellContext`height, $CellContext`v, $CellContext`w, $CellContext`i}, \
$CellContext`norm1 = Norm[$CellContext`pt1]; $CellContext`norm2 = 
          Norm[$CellContext`pt2]; $CellContext`proj = (
            Dot[$CellContext`pt1, $CellContext`pt2]/$CellContext`norm2^2) \
$CellContext`pt2; $CellContext`dotproduct = 
          Dot[$CellContext`pt1, $CellContext`pt2]; $CellContext`height = 
          Norm[$CellContext`pt1 - $CellContext`proj]; $CellContext`angle = (
            180./Pi) 
           ArcCos[Dot[$CellContext`pt1, $CellContext`pt2]/($CellContext`norm1 \
$CellContext`norm2)]; $CellContext`graphics = {Red, 
            Arrow[{{0, 0}, $CellContext`pt1}], Green, 
            Arrow[{{0, 0}, $CellContext`pt2}], Blue, 
            Arrow[{$CellContext`pt2, $CellContext`pt1}], Black, 
            Line[{$CellContext`proj, $CellContext`pt1}], 
            Text[
            "\!\(\*OverscriptBox[\(v\), \(\[RightVector]\)]\)", \
$CellContext`pt1/2, {0, 1.5}], 
            Text[
            "\[Theta]", (($CellContext`pt1 + $CellContext`pt2)/
              Norm[$CellContext`pt1 + $CellContext`pt2]) (1/2)], 
            Text[
            "\!\(\*OverscriptBox[\(w\), \(\[RightVector]\)]\)", \
$CellContext`pt2/2, {0, 1.5}], 
            Text[
            "\!\(\*OverscriptBox[\(v\), \
\(\[RightVector]\)]\)-\!\(\*OverscriptBox[\(w\), \(\[RightVector]\)]\)", \
($CellContext`pt1 + $CellContext`pt2)/2, {0, -1.5}], 
            Text["H", ($CellContext`proj + $CellContext`pt1)/2, {0, -1}]}; 
         Return[
           Column[{
             Show[
              Graphics[$CellContext`graphics], ImageSize -> 300, Axes -> True,
               Ticks -> {
                Table[$CellContext`i, {$CellContext`i, -5, 5}], 
                Table[$CellContext`i, {$CellContext`i, -5, 15}]}, 
              PlotRange -> {{-5, 5}, {-5, 5}}], 
             
             Row[{"\!\(\*OverscriptBox[\(v\), \(\[RightVector]\)]\) is the \
vector ", $CellContext`pt1}], 
             
             Row[{"\!\(\*OverscriptBox[\(w\), \(\[RightVector]\)]\) is the \
vector ", $CellContext`pt2}], 
             
             Row[{"The norm of \!\(\*OverscriptBox[\(v\), \(\[RightVector]\)]\
\) is ", 
               Norm[$CellContext`pt1]}], 
             
             Row[{"The norm of \!\(\*OverscriptBox[\(w\), \(\[RightVector]\)]\
\) is ", 
               Norm[$CellContext`pt2]}], 
             Row[{
              "The dot product of \!\(\*OverscriptBox[\(v\), \(\[RightVector]\
\)]\) and \!\(\*OverscriptBox[\(w\), \(\[RightVector]\)]\) is ", \
$CellContext`dotproduct}], 
             Row[{"The area is", 
               DisplayForm[
                Sqrt[
                OverVector[$CellContext`v]^2 OverVector[$CellContext`w]^2 - 
                 CenterDot[
                   OverVector[$CellContext`v], 
                   OverVector[$CellContext`w]]^2]], " = ", 
               Sqrt[
               Norm[$CellContext`pt1]^2 
                 Norm[$CellContext`pt2]^2 - $CellContext`dotproduct^2]}], 
             Row[{"The angle \[Theta] is ", $CellContext`angle, " degrees"}], 
             
             Row[{"The height H is ", $CellContext`height}]}]]]}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.48198443430895*^9, 3.481984454297886*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{640, 750},
WindowMargins->{{12, Automatic}, {Automatic, 24}},
ShowSelection->True,
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 99, 1, 57, "Subtitle"],
Cell[669, 25, 1702, 49, 181, "Text"],
Cell[2374, 76, 8140, 206, 23, "Input",
 CellOpen->False],
Cell[CellGroupData[{
Cell[10539, 286, 939, 24, 23, "Input",
 CellOpen->False],
Cell[11481, 312, 6118, 123, 637, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17636, 440, 642, 19, 23, "Input",
 CellOpen->False],
Cell[18281, 461, 5238, 110, 695, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
