(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     14020,        362]
NotebookOptionsPosition[     13507,        339]
NotebookOutlinePosition[     13848,        354]
CellTagsIndexPosition[     13805,        351]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Example 6.4.3", "Subtitle",
 CellChangeTimes->{{3.481904344880021*^9, 3.481904347254346*^9}, {
   3.4918330689442*^9, 3.491833069757598*^9}, 3.4918334981200247`*^9, 
   3.491833862282536*^9}],

Cell[TextData[{
 "This notebook shows the geometric interpretation of vector projection for \
3-dimensional vectors given in example 6.4.3.  Given vectors ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["v", "\[RightVector]"], TraditionalForm]]],
 " (in blue) and ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["w", "\[RightVector]"], TraditionalForm]]],
 " (in green),  the projection of ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["w", "\[RightVector]"], TraditionalForm]]],
 " onto ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["v", "\[RightVector]"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["proj", 
     OverscriptBox["v", "\[RightVector]"]], "(", 
    OverscriptBox["w", "\[RightVector]"], ")"}], TraditionalForm]]],
 ", is given in red. The vectors ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["w", "\[RightVector]"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["v", "\[RightVector]"], TraditionalForm]]],
 " are entered in the corresponding input fields.  Because the projection \
takes place in three dimensions perspective may make it hard to see what it \
going on, so you are able to rotate the picture freely and the space the \
projection would take place through (i.e. where ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["w", "\[RightVector]"], TraditionalForm]]],
 " would pass through as it is projected on to ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["v", "\[RightVector]"], TraditionalForm]]],
 ") is slightly shaded to emphasize the projection."
}], "Text",
 CellChangeTimes->{{3.4819043503681383`*^9, 3.4819045237487307`*^9}, {
   3.491833079665924*^9, 3.491833272259077*^9}, {3.4918335118906317`*^9, 
   3.491833763047022*^9}, 3.491833903580463*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DisplayProjectedVector3D", "[", 
   RowBox[{"w_", ",", "v_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "graphics", ",", " ", "proj", ",", " ", "perpendicular", ",", "ticks", 
      ",", "max", ",", "k"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"proj", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"w", ".", "v"}], "/", 
        RowBox[{"v", ".", "v"}]}], " ", "v"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"perpendicular", "=", 
      RowBox[{"w", "-", "proj"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"max", "=", 
      RowBox[{"Ceiling", "[", 
       RowBox[{"Max", "[", " ", 
        RowBox[{
         RowBox[{"Norm", "[", "w", "]"}], ",", " ", 
         RowBox[{"Norm", "[", "v", "]"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ticks", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"k", ",", " ", 
        RowBox[{"{", 
         RowBox[{"k", ",", 
          RowBox[{"-", 
           RowBox[{"Ceiling", "[", "max", "]"}]}], ",", " ", 
          RowBox[{"Ceiling", "[", "max", "]"}], ",", 
          RowBox[{"Ceiling", "[", 
           RowBox[{"max", "/", "4."}], "]"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"graphics", "=", 
      RowBox[{"Graphics3D", "[", 
       RowBox[{"{", 
        RowBox[{"Thick", ",", "Blue", ",", " ", 
         RowBox[{"Arrow", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "v"}], "}"}], 
          "]"}], ",", " ", "Green", ",", 
         RowBox[{"Arrow", "[", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", " ", "w"}], "}"}],
           "]"}], ",", " ", "Red", ",", 
         RowBox[{"Arrow", "[", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "proj"}], "}"}], 
          "]"}], ",", " ", "Black", ",", 
         RowBox[{"Text", "[", " ", 
          RowBox[{"\"\<w\>\"", ",", " ", 
           RowBox[{"w", "+", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{".05", ",", ".05", ",", ".05"}], "}"}], "max"}]}]}], 
          "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"\"\<v\>\"", ",", " ", 
           RowBox[{"v", "+", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{".05", ",", 
               RowBox[{"-", ".2"}], ",", ".05"}], "}"}], "max"}]}]}], "]"}], 
         ",", " ", "Red", ",", 
         RowBox[{"Opacity", "[", ".1", "]"}], ",", 
         RowBox[{"Polygon", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", " ", "proj", ",", 
            " ", "w"}], "}"}], "]"}]}], "}"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Return", "[", " ", 
      RowBox[{"Column", "[", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Show", "[", 
          RowBox[{"graphics", ",", " ", 
           RowBox[{"Ticks", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"ticks", ",", "ticks", ",", "ticks"}], "}"}]}], ",", " ", 
           RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", " ", 
           RowBox[{"Axes", "\[Rule]", "True"}], ",", " ", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "max"}], ",", "max"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "max"}], ",", "max"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "max"}], ",", "max"}], "}"}]}], "}"}]}], ",", 
           " ", 
           RowBox[{"ImageSize", "\[Rule]", "300"}], ",", 
           RowBox[{"AxesLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\""}], 
             "}"}]}], ",", " ", 
           RowBox[{"AxesEdge", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", 
                RowBox[{"-", "1"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", 
                RowBox[{"-", "1"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", 
                RowBox[{"-", "1"}]}], "}"}]}], "}"}]}], ",", 
           RowBox[{
           "PlotLabel", "\[Rule]", " ", 
            "\"\<Projection of w onto v is in red\>\""}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Row", "[", " ", 
          RowBox[{"{", 
           RowBox[{
           "\"\<The vector projection of the vector w \>\"", ",", " ", "w", 
            ",", " ", "\"\< in green onto the vector v \>\"", ",", "v", ",", 
            "\"\< in blue is the red vector \>\"", ",", " ", "proj"}], "}"}], 
          "]"}]}], "}"}], "]"}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.491772656120125*^9, 3.4917726650499287`*^9}, {
  3.491772722220976*^9, 3.491772791627935*^9}, {3.491772861820405*^9, 
  3.491772994713485*^9}, {3.491773065630723*^9, 3.4917732339318857`*^9}, {
  3.4917733025627213`*^9, 3.491773315552863*^9}, {3.491773351212728*^9, 
  3.4917733514824266`*^9}, {3.491773389013056*^9, 3.491773448727215*^9}, {
  3.491773488379277*^9, 3.491773683035573*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"DisplayProjectedVector3D", "[", 
    RowBox[{"w", ",", "v"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"w", ",", 
       RowBox[{"{", 
        RowBox[{"5", ",", "0", ",", "0"}], "}"}], ",", " ", 
       "\"\<Project the green vector w \>\""}], "}"}], ",", " ", 
     "InputField"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"v", ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4", ",", "4"}], "}"}], ",", 
       "\"\<Onto the blue vector v \>\""}], "}"}], ",", "InputField"}], "}"}],
    ",", " ", 
   RowBox[{"SaveDefinitions", "\[Rule]", " ", "True"}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.491773000366102*^9, 3.491773011080585*^9}, {
  3.491773243382056*^9, 3.491773279277771*^9}, {3.49183334464178*^9, 
  3.491833479361783*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`v$$ = {4, 4, 4}, $CellContext`w$$ = {5, 0, 
    0}, Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`w$$], {5, 0, 0}, "Project the green vector w "}}, {{
       Hold[$CellContext`v$$], {4, 4, 4}, "Onto the blue vector v "}}}, 
    Typeset`size$$ = {774., {239.71875, 246.28125}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`v$$ = {4, 4, 4}, $CellContext`w$$ = {5, 0, 
         0}}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`DisplayProjectedVector3D[$CellContext`w$$, \
$CellContext`v$$], 
      "Specifications" :> {{{$CellContext`w$$, {5, 0, 0}, 
          "Project the green vector w "}, ControlType -> 
         InputField}, {{$CellContext`v$$, {4, 4, 4}, 
          "Onto the blue vector v "}, ControlType -> InputField}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{827., {307.21875, 313.78125}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`DisplayProjectedVector3D[
         Pattern[$CellContext`w, 
          Blank[]], 
         Pattern[$CellContext`v, 
          Blank[]]] := 
       Block[{$CellContext`graphics, $CellContext`proj, \
$CellContext`perpendicular, $CellContext`ticks, $CellContext`max, \
$CellContext`k}, $CellContext`proj = (Dot[$CellContext`w, $CellContext`v]/
            Dot[$CellContext`v, $CellContext`v]) $CellContext`v; \
$CellContext`perpendicular = $CellContext`w - $CellContext`proj; \
$CellContext`max = Ceiling[
            Max[
             Norm[$CellContext`w], 
             Norm[$CellContext`v]]]; $CellContext`ticks = 
          Table[$CellContext`k, {$CellContext`k, -Ceiling[$CellContext`max], 
             Ceiling[$CellContext`max], 
             Ceiling[$CellContext`max/4.]}]; $CellContext`graphics = 
          Graphics3D[{Thick, Blue, 
             Arrow[{{0, 0, 0}, $CellContext`v}], Green, 
             Arrow[{{0, 0, 0}, $CellContext`w}], Red, 
             Arrow[{{0, 0, 0}, $CellContext`proj}], Black, 
             Text["w", $CellContext`w + {0.05, 0.05, 0.05} $CellContext`max], 
             Text["v", $CellContext`v + {0.05, -0.2, 0.05} $CellContext`max], 
             Red, 
             Opacity[0.1], 
             Polygon[{{0, 0, 0}, $CellContext`proj, $CellContext`w}]}]; Return[
           Column[{
             
             Show[$CellContext`graphics, 
              Ticks -> {$CellContext`ticks, $CellContext`ticks, \
$CellContext`ticks}, AspectRatio -> Automatic, Axes -> True, 
              PlotRange -> {{-$CellContext`max, $CellContext`max}, \
{-$CellContext`max, $CellContext`max}, {-$CellContext`max, $CellContext`max}},
               ImageSize -> 300, AxesLabel -> {"x", "y", "z"}, 
              AxesEdge -> {{-1, -1}, {-1, -1}, {-1, -1}}, PlotLabel -> 
              "Projection of w onto v is in red"], 
             
             Row[{"The vector projection of the vector w ", $CellContext`w, 
               " in green onto the vector v ", $CellContext`v, 
               " in blue is the red vector ", $CellContext`proj}]}]]]}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.491773014201427*^9, 3.4917731635912*^9, {3.491773212316197*^9, 
   3.491773279770797*^9}, 3.4917733171091137`*^9, 3.491773353075506*^9, {
   3.491773436798074*^9, 3.491773451311843*^9}, 3.491773490087056*^9, {
   3.4917735461022377`*^9, 3.491773596917653*^9}, 3.491773652214222*^9, 
   3.4917736848356247`*^9, 3.491833324619158*^9, 3.491833407560103*^9, 
   3.491833443947257*^9, 3.491833480269538*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{973, 719},
WindowMargins->{{278, Automatic}, {Automatic, 62}},
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 197, 3, 57, "Subtitle"],
Cell[767, 27, 1746, 48, 117, "Text"],
Cell[2516, 77, 5662, 143, 23, "Input",
 CellOpen->False],
Cell[CellGroupData[{
Cell[8203, 224, 897, 25, 23, "Input",
 CellOpen->False],
Cell[9103, 251, 4376, 84, 641, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
