(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     20732,        538]
NotebookOptionsPosition[     20000,        511]
NotebookOutlinePosition[     20369,        527]
CellTagsIndexPosition[     20326,        524]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Example 8.5.1 - Gram-Schmidt Orthonormalization", "Subtitle",
 CellChangeTimes->{{3.492265658687275*^9, 3.4922656832935057`*^9}}],

Cell[TextData[{
 "This notebook defines two functions, ",
 StyleBox["GramSchmidt",
  FontWeight->"Bold"],
 " and ",
 StyleBox["GramSchmidtVerbose",
  FontWeight->"Bold"],
 ", which perform the process of Gram-Schmidt orthonomalization outlined in \
example 8.5.1.  When you perform the first evaluation anywhere in this \
notebook, you will get a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " dialog window to evaluate the cells containing the code and define the \
functions.  If you did not get this window or selected \"no\" in the window, \
you may define the functions by clicking on the collapsed cell below this \
paragraph (the bracket is small on the right edge of the notebook) and \
evaluating it."
}], "Text",
 CellChangeTimes->{{3.492857243683877*^9, 3.492857306045101*^9}, {
   3.492857340140963*^9, 3.492857496356715*^9}, {3.492857534350305*^9, 
   3.492857578044931*^9}, {3.492859519719512*^9, 3.492859538706439*^9}, 
   3.492859623509658*^9, 3.492859665468882*^9, {3.49285972909239*^9, 
   3.492859736650025*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"GramSchmidt", "[", "vectors_", "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Block", "[", " ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"orthonormals", ",", "k", ",", "tempvector", ",", "j"}], "}"}],
       ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"!", 
          RowBox[{"MatrixQ", "[", "vectors", "]"}]}], ",", " ", 
         RowBox[{
          RowBox[{
          "Print", "[", "\"\<Not all vectors have the same length.\>\"", 
           "]"}], ";", 
          RowBox[{"Return", "[", "]"}]}]}], " ", "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", " ", 
        RowBox[{
         RowBox[{"!", 
          RowBox[{
           RowBox[{"Union", "[", " ", 
            RowBox[{"Map", "[", 
             RowBox[{"NumericQ", ",", 
              RowBox[{"Flatten", "[", "vectors", "]"}]}], "]"}], "]"}], 
           "\[Equal]", 
           RowBox[{"{", "True", "}"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
          "Print", "[", " ", 
           "\"\<Not all the vector components are numeric\>\"", "]"}], ";", 
          RowBox[{"Return", "[", "]"}]}]}], " ", "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"orthonormals", "=", 
        RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Do", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Which", "[", " ", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", "orthonormals", "]"}], "\[Equal]", "0"}], 
            " ", "&&", " ", 
            RowBox[{
             RowBox[{"Union", "[", 
              RowBox[{"vectors", "[", 
               RowBox[{"[", "k", "]"}], "]"}], "]"}], "\[NotEqual]", 
             RowBox[{"{", "0", "}"}]}]}], ",", " ", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"orthonormals", ",", 
             RowBox[{
              RowBox[{"vectors", "[", 
               RowBox[{"[", "k", "]"}], "]"}], "/", 
              RowBox[{"Simplify", "[", 
               RowBox[{"Norm", "[", 
                RowBox[{"vectors", "[", 
                 RowBox[{"[", "k", "]"}], "]"}], " ", "]"}], " ", "]"}]}]}], 
            "]"}], " ", ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", "orthonormals", "]"}], "\[Equal]", "0"}], 
            " ", "&&", " ", 
            RowBox[{
             RowBox[{"Union", "[", 
              RowBox[{"vectors", "[", 
               RowBox[{"[", "k", "]"}], "]"}], " ", "]"}], "\[Equal]", 
             RowBox[{"{", "0", "}"}]}]}], ",", "True", ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Union", "[", " ", 
             RowBox[{"tempvector", "=", 
              RowBox[{"FullSimplify", "[", 
               RowBox[{
                RowBox[{"vectors", "[", 
                 RowBox[{"[", "k", "]"}], "]"}], "-", 
                RowBox[{"Sum", "[", " ", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"vectors", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], ".", 
                    RowBox[{"orthonormals", "[", 
                    RowBox[{"[", "j", "]"}], "]"}]}], " ", 
                   RowBox[{"orthonormals", "[", 
                    RowBox[{"[", "j", "]"}], "]"}]}], ",", 
                  RowBox[{"{", 
                   RowBox[{"j", ",", "1", ",", 
                    RowBox[{"Length", "[", "orthonormals", "]"}]}], "}"}]}], 
                 "]"}]}], "]"}]}], "]"}], "\[NotEqual]", 
            RowBox[{"{", "0", "}"}]}], ",", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"orthonormals", " ", ",", " ", 
             RowBox[{"tempvector", "/", 
              RowBox[{"Simplify", "[", 
               RowBox[{"Norm", "[", "tempvector", "]"}], "]"}]}]}], "]"}], 
           ",", "True", ",", "True"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "1", ",", 
           RowBox[{"Length", "[", "vectors", "]"}]}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Return", "[", "orthonormals", "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"GramSchmidtVerbose", "[", "vectors_", "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"Block", "[", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"orthonormals", ",", "k", ",", "tempvector", ",", "j"}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"!", 
         RowBox[{"MatrixQ", "[", "vectors", "]"}]}], ",", " ", 
        RowBox[{
         RowBox[{
         "Print", "[", "\"\<Not all vectors have the same length.\>\"", "]"}],
          ";", 
         RowBox[{"Return", "[", "]"}]}]}], " ", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", " ", 
       RowBox[{
        RowBox[{"!", 
         RowBox[{
          RowBox[{"Union", "[", " ", 
           RowBox[{"Map", "[", 
            RowBox[{"NumericQ", ",", 
             RowBox[{"Flatten", "[", "vectors", "]"}]}], "]"}], "]"}], 
          "\[Equal]", 
          RowBox[{"{", "True", "}"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
         "Print", "[", " ", 
          "\"\<Not all the vector components are numeric\>\"", "]"}], ";", 
         RowBox[{"Return", "[", "]"}]}]}], " ", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"orthonormals", "=", 
       RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Do", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"Which", "[", " ", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", "orthonormals", "]"}], "\[Equal]", "0"}], 
            " ", "&&", " ", 
            RowBox[{
             RowBox[{"Union", "[", 
              RowBox[{"vectors", "[", 
               RowBox[{"[", "k", "]"}], "]"}], "]"}], "\[NotEqual]", 
             RowBox[{"{", "0", "}"}]}]}], ",", " ", 
           RowBox[{
            RowBox[{"AppendTo", "[", 
             RowBox[{"orthonormals", ",", 
              RowBox[{
               RowBox[{"vectors", "[", 
                RowBox[{"[", "k", "]"}], "]"}], "/", 
               RowBox[{"Simplify", "[", 
                RowBox[{"Norm", "[", 
                 RowBox[{"vectors", "[", 
                  RowBox[{"[", "k", "]"}], "]"}], " ", "]"}], " ", "]"}]}]}], 
             "]"}], " ", ";", 
            RowBox[{"Print", "[", " ", 
             RowBox[{
             "\"\<The current orthonormal set is empty, adding the \
normaliztion of \>\"", ",", " ", 
              RowBox[{"vectors", "[", 
               RowBox[{"[", "k", "]"}], "]"}], ",", " ", "\"\<, i.e.  \>\"", 
              ",", " ", 
              RowBox[{
               RowBox[{"vectors", "[", 
                RowBox[{"[", "k", "]"}], "]"}], "/", 
               RowBox[{"Simplify", "[", 
                RowBox[{"Norm", "[", 
                 RowBox[{"vectors", "[", 
                  RowBox[{"[", "k", "]"}], "]"}], " ", "]"}], " ", "]"}]}], 
              ",", " ", "\"\< to the list.\>\""}], "]"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", "orthonormals", "]"}], "\[Equal]", "0"}], 
            " ", "&&", " ", 
            RowBox[{
             RowBox[{"Union", "[", 
              RowBox[{"vectors", "[", 
               RowBox[{"[", "k", "]"}], "]"}], " ", "]"}], "\[Equal]", 
             RowBox[{"{", "0", "}"}]}]}], ",", 
           RowBox[{
           "Print", "[", 
            "\"\<The current orthonormal set is empty, but the zero vector \
cannot be normalized/added.\>\"", "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Union", "[", " ", 
             RowBox[{"tempvector", "=", 
              RowBox[{"FullSimplify", "[", 
               RowBox[{
                RowBox[{"vectors", "[", 
                 RowBox[{"[", "k", "]"}], "]"}], "-", 
                RowBox[{"Sum", "[", " ", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"vectors", "[", 
                    RowBox[{"[", "k", "]"}], "]"}], ".", 
                    RowBox[{"orthonormals", "[", 
                    RowBox[{"[", "j", "]"}], "]"}]}], " ", 
                   RowBox[{"orthonormals", "[", 
                    RowBox[{"[", "j", "]"}], "]"}]}], ",", 
                  RowBox[{"{", 
                   RowBox[{"j", ",", "1", ",", 
                    RowBox[{"Length", "[", "orthonormals", "]"}]}], "}"}]}], 
                 "]"}]}], "]"}]}], "]"}], "\[NotEqual]", 
            RowBox[{"{", "0", "}"}]}], ",", 
           RowBox[{
            RowBox[{"AppendTo", "[", 
             RowBox[{"orthonormals", " ", ",", " ", 
              RowBox[{"tempvector", "/", 
               RowBox[{"Simplify", "[", 
                RowBox[{"Norm", "[", "tempvector", "]"}], "]"}]}]}], "]"}], 
            ";", "\[IndentingNewLine]", 
            RowBox[{"Print", "[", 
             RowBox[{"\"\<The vector \>\"", ",", 
              RowBox[{"vectors", "[", 
               RowBox[{"[", "k", "]"}], "]"}], ",", " ", 
              "\"\< is independent of the vectors in the current orthonormal \
set so taking away its projections onto those vectors and normalizing, adding \
\>\"", ",", 
              RowBox[{"tempvector", "/", 
               RowBox[{"Simplify", "[", 
                RowBox[{"Norm", "[", "tempvector", "]"}], "]"}]}], ",", " ", 
              "\"\< to the set.\>\""}], "]"}]}], ",", "True", ",", 
           RowBox[{"Print", "[", 
            RowBox[{"\"\<The vector \>\"", ",", " ", 
             RowBox[{"vectors", "[", 
              RowBox[{"[", "k", "]"}], "]"}], ",", " ", 
             "\"\<is dependent on the vectors currently in the orthonormal \
list, so no new vector is being added.\>\""}], "]"}]}], "]"}], 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"k", "<", 
            RowBox[{"Length", "[", "vectors", "]"}]}], ",", 
           RowBox[{"Print", "[", " ", 
            RowBox[{
            "\"\<The current orthonormal set is \>\"", ",", "orthonormals"}], 
            "]"}], ",", " ", 
           RowBox[{
           "Print", "[", "\"\<The final orthonormal set is\>\"", "]"}]}], 
          "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", 
          RowBox[{"Length", "[", "vectors", "]"}]}], "}"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Return", "[", "orthonormals", "]"}]}]}], "\[IndentingNewLine]",
     "]"}]}], ";"}]}], "Input",
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 InitializationCell->True,
 CellChangeTimes->{{3.492262931959692*^9, 3.492263127143084*^9}, {
   3.492263182095777*^9, 3.492263295601129*^9}, {3.492263349362648*^9, 
   3.4922634753559303`*^9}, {3.492263509413886*^9, 3.492263604677085*^9}, {
   3.4922636346805763`*^9, 3.49226365233496*^9}, {3.492263806065168*^9, 
   3.4922638549675207`*^9}, {3.4922639064254313`*^9, 
   3.4922639093425426`*^9}, {3.49226398984988*^9, 3.492264070314053*^9}, {
   3.492264126244389*^9, 3.4922641719408913`*^9}, {3.492264465836589*^9, 
   3.4922644808100557`*^9}, 3.4922656440204067`*^9, 3.492266519346887*^9, {
   3.4923410520630693`*^9, 3.492341091807909*^9}, 3.4928595904377003`*^9}],

Cell[TextData[{
 "Both commands take in a set of vectors and construct a new set of vectors \
from those which are of length one, pairwise orthogonal, and have the same \
span.  The input is a set of vectors, all of which must have the same length \
(i.e. the first vector cannot be 2-dimensional anf the second 3-dimensional). \
 In addition, each vector must be composed of numbers rather than variables \
(although vectors with complex numbers are allowed).  No assmuptions are made \
about linear dependence or independence.  The specific procedure used is as \
follows:\n\nGiven a set of vectors V, build an orthonormal set B from them \
by:\n\n1) If the first vector of V is the zero vector, throw it out and start \
over.\n2) If the first vector of V is nonzero, divide it by its length (i.e. \
normalize it) and add it to the set B.  Proceed to step 3.\n3) For the next \
vector ",
 Cell[BoxData[
  FormBox[
   OverscriptBox[
    SubscriptBox["v", "i"], "\[RightVector]"], TraditionalForm]]],
 " in V and B={",
 Cell[BoxData[
  FormBox[
   OverscriptBox[
    SubscriptBox["b", "1"], "\[RightVector]"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   OverscriptBox[
    SubscriptBox["b", "2"], "\[RightVector]"], TraditionalForm]]],
 ", .... ",
 Cell[BoxData[
  FormBox[
   OverscriptBox[
    SubscriptBox["b", "j"], "\[RightVector]"], TraditionalForm]]],
 "}, form the new vector ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["b", "\[RightVector]"], "=", " ", 
    RowBox[{
     OverscriptBox[
      SubscriptBox["v", "i"], "\[RightVector]"], "-", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "1"}], "j"], 
      RowBox[{
       SubscriptBox["proj", 
        OverscriptBox[
         SubscriptBox["b", "k"], "\[RightVector]"]], "(", 
       OverscriptBox[
        SubscriptBox["v", "i"], "\[RightVector]"], ")"}]}]}]}], 
   TraditionalForm]]],
 ". If V has no more vectors, stop and return the set B as your orthnormal \
set.\n4) If the vector ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["b", "\[RightVector]"], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   OverscriptBox["0", "\[RightVector]"], TraditionalForm]]],
 ", add nothing to B (as ",
 Cell[BoxData[
  FormBox[
   OverscriptBox[
    SubscriptBox["v", "i"], "\[RightVector]"], TraditionalForm]]],
 " was dependent on previous vectors), and go back to step 3 starting with  \
",
 Cell[BoxData[
  FormBox[
   OverscriptBox[
    SubscriptBox["v", 
     RowBox[{"i", "+", "1"}]], "\[RightVector]"], TraditionalForm]]],
 ".  \n5) If the vector ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["b", "\[RightVector]"], TraditionalForm]]],
 "\[NotEqual]",
 Cell[BoxData[
  FormBox[
   OverscriptBox["0", "\[RightVector]"], TraditionalForm]]],
 ", normalize the vector ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["b", "\[RightVector]"], TraditionalForm]]],
 " and add the normaized vector to the set B as  ",
 Cell[BoxData[
  FormBox[
   OverscriptBox[
    SubscriptBox["b", 
     RowBox[{"j", "+", "1"}]], "\[RightVector]"], TraditionalForm]]],
 " and return to step 3.\n\nSome notes about ",
 StyleBox["GramScmidt",
  FontWeight->"Bold"],
 " and ",
 StyleBox["GramSchmidtVerbose",
  FontWeight->"Bold"],
 ":\n\n1) The only difference between ",
 StyleBox["GramSchmidt",
  FontWeight->"Bold"],
 " and ",
 StyleBox["GramSchmidtVerbose",
  FontWeight->"Bold"],
 " is that the \"verbose\" version prints out information about each step of \
the process so you can follow along.\n2) Both commands check to make sure the \
vectors contain only numbers and have the same dimension.\n3) The result of \
the process is dependent on the order of the vectors (although you will \
always get an orthonormal set, the exact set you get can change if you switch \
vectors around).\n4) If the vectors have exact numbers in their components, \
all of the arithmetic will be done exactly.  So for either larger sets of \
vectors or high-dimension vectors, expect lots of large square roots because \
of the normalizations.\n5) If you give either command a set of zero vectors, \
an empty set will be returned.\n\nBelow are some examples of the commands:"
}], "Text",
 CellChangeTimes->{{3.492857592236581*^9, 3.4928576564445066`*^9}, {
   3.4928576885420923`*^9, 3.492858310755539*^9}, {3.4928583598222713`*^9, 
   3.4928585867877693`*^9}, {3.492858631508462*^9, 3.492859012562936*^9}, {
   3.49285905375029*^9, 3.4928590671384068`*^9}, 3.492859693428166*^9}],

Cell[BoxData[
 RowBox[{"GramSchmidt", "[", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "0", ",", "1"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"2", ",", "1", ",", "4"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"3", ",", "1", ",", "6"}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.492859069091154*^9, 3.4928590855320683`*^9}, 
   3.492859749147341*^9}],

Cell[BoxData[
 RowBox[{"GramSchmidt", "[", " ", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "1", ",", "4"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"3", ",", "1", ",", "5"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.49285912940515*^9, 3.492859133236073*^9}}],

Cell[BoxData[
 RowBox[{"GramSchmidtVerbose", "[", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "2", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "1", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", "3", ",", "4"}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.4928590940075073`*^9, 3.492859118211965*^9}}],

Cell[BoxData[
 RowBox[{"GramSchmidt", "[", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", "2", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4", ",", "6"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"6", ",", "7", ",", "8"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "1", ",", "2"}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.492859147758017*^9, 3.492859175891308*^9}}],

Cell[BoxData[
 RowBox[{"GramSchmidt", "[", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "0", ",", "I"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"2", "+", "I"}], ",", "3", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"I", ",", 
      RowBox[{"-", "I"}], ",", " ", 
      RowBox[{"1", "+", "I"}]}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.492859180011632*^9, 3.4928591980201197`*^9}}]
}, Open  ]]
},
AutoGeneratedPackage->None,
WindowSize->{983, 1151},
WindowMargins->{{203, Automatic}, {Automatic, 0}},
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 135, 1, 57, "Subtitle"],
Cell[705, 25, 1039, 22, 107, "Text"],
Cell[1747, 49, 11597, 274, 23, "Input",
 CellOpen->False,
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 InitializationCell->True],
Cell[13347, 325, 4461, 115, 533, "Text"],
Cell[17811, 442, 413, 11, 33, "Input"],
Cell[18227, 455, 384, 10, 33, "Input"],
Cell[18614, 467, 384, 10, 33, "Input"],
Cell[19001, 479, 517, 14, 33, "Input"],
Cell[19521, 495, 463, 13, 33, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
